Summary: The Linux RT kernel

# build parallelism:
%{!?_smp_mflags:%define _smp_mflags --jobs=8}

# realtime kernels are named "kernel-rt"
%define kernel kernel
%define realtime rt

%define iteration 108

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define buildrt 0
%define builddoc 0
%define builddebug 1
%define buildheaders 0
%define buildvanilla 0
%define buildtrace 0
%define buildkabi 0

%define _enable_debug_packages 1

# Versions of various parts

%define base_sublevel 24

# all of this is to handle the differences between building
# from a released kernel tarball and a release-candidate (rc)
# tarball
%define released_kernel 1

## If this is a released kernel ##
%if 0%{?released_kernel}
%define upstream_sublevel %{base_sublevel}
# Do we have a 2.6.21.y update to apply?
%define stable_update 7
# Set rpm version accordingly
%if 0%{?stable_update}
%define stablerev .%{stable_update}
%endif
%define rpmversion 2.6.%{base_sublevel}%{?stablerev}

## The not-released-kernel case ##
%else
# The next upstream release sublevel (base_sublevel+1)
%define upstream_sublevel %(expr %{base_sublevel} + 1)
# The rc snapshot level
%define rcrev 0
# Set rpm version accordingly
%define rpmversion 2.6.%{upstream_sublevel}
%endif

# pkg_release is what we'll fill in for the rpm Release field
%if 0%{?released_kernel}
%define pkg_release %{iteration}%{?buildid}%{?dist}
%else
%if 0%{?rcrev}
%define rctag .rc%rcrev
%endif
%if 0%{?gitrev}
%define gittag .git%gitrev
%if !0%{?rcrev}
%define rctag .rc0
%endif
%endif
%define pkg_release 0.%{iteration}%{?rctag}%{?gittag}%{?buildid}%{?dist}
%endif

# The kernel tarball/base version
%define kversion 2.6.%{base_sublevel}

%define signmodules 0
%define make_target bzImage
%define kernel_image x86

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}
%define hdrarch %_target_cpu

# groups of related archs
%define all_x86 i386 i686
# we differ here b/c of the reloc patches

# Override generic defaults with per-arch defaults

%ifarch noarch
%define builddoc 1
%define buildheaders 0
%define builddebug 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-*.config
%endif

# Second, per-architecture exclusions (ifarch)

%ifarch ppc64iseries i686 i586
%define buildheaders 0
%endif

%ifarch %{all_x86}
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-i?86*.config
%define image_install_path boot
%define signmodules 0
%define hdrarch i386
%endif

%ifarch i686
%define buildrt 1
%define buildtrace 1
%define buildvanilla 1
%endif

%ifarch x86_64
%define buildrt 1
%define buildtrace 1
%define buildvanilla 1
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-x86_64*.config
%define image_install_path boot
%define signmodules 0
%endif

%ifarch ppc64 ppc64iseries
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-ppc64*.config
%define image_install_path boot
%define signmodules 0
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define hdrarch powerpc
%endif

%ifarch sparc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-sparc.config
%define make_target image
%define kernel_image image
%endif

%ifarch sparc64
%define buildsmp 1
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-sparc64*.config
%define make_target image
%define kernel_image image
%endif

%ifarch ppc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-ppc{-,.}*config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define buildsmp 1
%define hdrarch powerpc
%endif

%if %{buildrt}
%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-x86_64-rt*.config
%endif
%ifarch i686
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{rpmversion}-i?86-rt*.config
%endif
%endif

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386 or s390x -- we only do kernel-headers there.
%define nobuildarches i386 s390

%ifarch %nobuildarches
%define buildsmp 0
%define buildpae 0
#%define _enable_debug_packages 0
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, selinux-policy-targeted < 1.25.3-14

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%define xen_conflicts glibc < 2.3.5-1, xen < 3.0.1

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 4.2.21-1

Name: %{kernel}-%{realtime}
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{pkg_release}
ExclusiveArch: noarch i686 x86_64
ExclusiveOS: Linux
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1}\
Provides: kernel-rt = %{rpmversion}
Provides: kernel-rt-drm = 4.3.0
Provides: kernel-rt-%{_target_cpu} = %{rpmversion}-%{pkg_release}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}

#
# prevent the x86 kernel-rt package from being picked up by yum
# on an x86_64 box (this prevents multilib behavior, yum special-cases
# the "kernel" package-name, but not the kernel-rt package name):
#
%ifarch x86_64
Conflicts: kernel-i686
%endif

# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes


#
# List the packages used during the kernel build
#
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils
%if %{signmodules}
BuildPreReq: gnupg
%endif
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
%if %{buildheaders}
BuildRequires: unifdef
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb

# Base kernel source
Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2

%if %{stable_update}
Source1: patch-%{rpmversion}.bz2
%endif

# current release candidate

Source2: Makefile.config

Source10: COPYING.modules
Source11: genkey
%if %{buildkabi}
Source12: kabitool
%endif
Source14: find-provides
Source15: merge.pl

Source20: config-debug
Source21: config-generic
Source22: config-i686-PAE
Source23: config-nodebug
Source24: config-rt
Source25: config-trace
Source26: config-vanilla
Source27: config-x86_64-generic
Source28: config-x86-generic

# START OF PATCH DEFINITIONS
Patch2: patch-2.6.24.7-rt14.bz2
Patch3: linux-2.6-dynticks-off-by-default.patch
Patch4: ibm-rmem-for-rtsj.patch
Patch5: aic94xx-inline-fw-rt.patch
Patch6: qla2xxx-inline-fw-rt.patch
Patch7: megaraid_sas.patch
Patch8: raw-spinlocks-for-nmi-print.patch
Patch9: linux-2.6-rt-oomkill.patch
Patch11: limit-i386-ram-to-16gb.patch
Patch12: RT-die.patch
Patch13: pci-nommconf-noseg.patch
Patch14: bz235099-idle-load-fix.patch
Patch16: RHEL-RT_AMD_TSC_sync_PN.patch
Patch17: RHEL5.1_fix_tscsync.patch
Patch18: linux-2.6-rt-quirky-ioapic-legacy-mask-unmask-workaround-jcm.patch
Patch19: preempt-irqs-x86-64-ioapic-mask-quirk-jcm.patch
Patch20: linux-2.6-vmsplice-fix.patch
Patch21: quiet-plit-warning.patch
Patch22: fix_misplaced_mb.patch
Patch23: linux-2.6.9-bonding-fix-stats-race.patch
Patch24: ofed-1.3.patch
Patch25: ofed-1.3-rt-compat.patch
Patch26: netxen_irq_and_napi.patch
Patch28: add-systems-to-ioapic-quirk.patch
Patch29: ibm-rtl-driver.patch
Patch30: ibm-amd-edac-rh-v1.patch
Patch31: ibm-refactor-opstate-RH-v1.patch
Patch32: ibm-hs21-tmid-fix.patch
Patch33: x86_fix_vsyscall_wreckage.patch
Patch42: 0001-x86-fix-32-bit-FRAME_POINTER-chasing-code.patch
Patch43: 0002-x86-add-the-capability-to-print-fuzzy-backtraces.patch
Patch44: 0003-x86-improve-the-32-bit-Frame-Pointer-backtracer-to.patch
Patch45: 0004-x86-pull-bp-calculation-earlier-into-the-backtrace.patch
Patch46: 0005-x86-turn-64-bit-x86-HANDLE_STACK-into-print_context.patch
Patch47: 0006-x86-use-the-stack-frames-to-get-exact-stack-traces.patch
Patch48: 0007-x86-add-a-simple-backtrace-test-module.patch
Patch49: 0008-x86-add-the-print-code-before-the-trapping-instruc.patch
Patch50: 0009-x86-make-printk_address-regs-ip-always-reliable.patch
Patch52: ioapic_quirk_i386-v2.patch
Patch54: vsyscall64_dummy_proc_entry.patch
Patch61: hrtimer-20080427.patch
Patch62: hrtimer-deadlock-fix.patch
Patch63: hrtimer-infinite-loop-fix.patch
Patch65: tsc-sync-fix.patch
Patch73: linux-2.6.24-pollfix.patch
Patch74: solarflare.patch
Patch75: fix_lock_inversion_in_direct_io.patch
Patch76: fix_journal_overflow_issues.patch
Patch80: rwlock-prio-fix.patch
Patch81: marker-stap-interface-for-MRG.patch
Patch82: rwlock-fixes.patch
Patch83: rwlock-torture.patch
Patch84: sched-use-a-2d-bitmap-search-prio-cpu-R.patch
Patch85: fix_kdump_crash_kernel_boot_memory_reservation_for_NUMA_machine.patch
Patch86: ftrace-wakeup-rawspinlock.patch
Patch88: ftrace-hotplug-fix-v2.patch
Patch89: radix-tree-lockdep-plus1.patch
# New Patches
Patch91: x86_64--ia32_syscall_restart_fix.patch
patch92: x86_64--ptrace_sign_extend_orig_rax_to_64bits.patch
Patch93: hotplug-slab.patch
Patch94: hotplug-page_alloc.patch
Patch95: hotplug-smp-bootstrap.patch
Patch96: hotplug-rcu.patch
Patch97: hotplug-idle_task_exit.patch
Patch98: hotplug-idle_task_exit_fix.patch
Patch99: mm--fix_race_in_COW_logic.patch
Patch100: rt_mutex-lock-underflow-fix.patch
Patch101: hrtimer-dont-migrate-raisesoftirq.patch
Patch102: fix_inotify_user_coalescing-bz453990.patch
Patch103: enqueue_task_flags.patch
Patch104: futex-bitset-backport.patch
Patch105: ppc64-fix_preempt_unsafe_access_to_per_cpu_variables.patch
Patch106: fix_sys_sched_rr_get_interval_slice_for_SCHED_FIFO_tasks.patch
Patch107: ftrace-fix-call-function-pointer.patch
Patch108: rwlock-be_more_conservative_in_locking_reader_lock_count.patch

# Security Fixes
Patch200: CVE-2007-6694--ppc-chrs-null-fix.patch
Patch201: CVE-2008-1615--linux-2.6-paranoid-iret.patch
Patch202: CVE-2008-1673--ans1_sanity_check_on_BER_decoding.patch
Patch203: CVE-2008-2136--missing_kfree_skb_on_pskb_may_pull.patch
# The patch below addresses the wrong CVE (BZ entries confusion)
Patch204: CVE-2008-2148--simplify_sched_fair.patch
Patch205: CVE-2007-6282--2.6.24.1_esp_iv_bug.patch
Patch207: sctp-fix_sctp_addr_overflow.patch
# Patch for the real CVE-2008-2148
Patch208: CVE-2008-2148--fix_utimensat_permissions_check.patch
patch209: CVE-2008-2372--reinstate_ZERO_PAGE_optimization_in_get_user_pages_and_fix_XIP.patch
Patch210: CVE-2008-2372--fix_ZERO_PAGE_breakage_with_vmware.patch
Patch211: alloc_stack_early.patch

# Patches from -rt17
Patch212: cpu-hotplug-fix-fix-fix.patch
Patch213: x86-64-fix-compile.patch
Patch214: trace-ktime-scalar.patch
Patch215: nfs-stats-miss-preemption.patch
Patch216: sched-fix-dequeued-race.patch
Patch217: trace-do-not-wakeup-when-irqs-disabled.patch
Patch218: acpi-fix-enter-c1.patch
Patch219: idle-fix.patch
Patch220: powerpc-xics-move-the-call-to-irq-radix-revmap-from-xics-startup-to-xics-host-map.patch
Patch221: powerpc-make-the-irq-reverse-mapping-radix-tree-lockless.patch
Patch222: cpu-hotplug-cpu-down-vs-preempt-rt_fix.patch
Patch224: fix-a-previously-reverted-fix.patch
Patch226: nommu-fix-build.patch
Patch227: pmtmr-override.patch
Patch228: bz457012--ipv6-use_timer_pending_mrg.patch
Patch229: bz457014--pppoe-check_packet_length_on_all_receive_paths.patch
Patch230: bz457019--pppoe-unshare_skb_before_anything_else_mrg.patch
Patch231: bz457027--ide-cd-fix_oops_when_using_growisofs_mrg.patch
Patch232: bz457507--tmpfs-fix_kernel_BUG_in_shmem_delete_inode.patch
Patch233: bz457705--fix_off-by-one_error_in_iov_iter_advance.patch
Patch234: bz457858--CVE-2008-3275-Linux_kernel_local_filesystem_DoS.patch
Patch235: bz457995--CVE-2008-3272-snd_seq_oss_synth_make_info_leak.patch
Patch236: linux-2.6-panic-on-oops.patch
Patch237: bz458016--random32-seeding_improvement_mrg.patch
Patch238: bz458340--parse_pmtmr-stores_ulong_in_u32.patch
Patch239: clean_-75_compile_warning.patch
Patch240: bz458350--cifs_asn1_comparison_always_false.patch
Patch241: bz458755--dlm-fix-possible-use-after-free.patch
Patch242: bz458756--dlm-check-for-null-in-device_write.patch
Patch243: bz458758--dlm-dlm-user.c-input-validation-fixes.patch
Patch244: rename_cpu_posix_timer.patch
Patch245: bz448574-increase-max-stack-trace-entries.patch
Patch246: 0001-lockdep-fix-combinatorial-explosion-in-lock-subgrap.patch
Patch247: 0001-lockdep-build-fix.patch
Patch248: 0002-lockdep-change-scheduler-annotation.patch
Patch249: 0004-lockdep-re-annotate-scheduler-runqueues.patch
Patch250: bz459141--ftrace-mcount-record-big.patch
Patch251: bz457507--CVE-2008-3534--fbdefio-add-set_page_dirty-handler-to-deferred-IO-FB.patch 
Patch252: bz459231--CVE-2008-3276--Linux_kernel_dccp_setsockopt_change.patch
Patch253: bz459462--binfmt_misc.c--avoid_potential_kernel_stack.patch
Patch254: bz459462--binfmt_misc.c--avoid_potential_kernel_stack_fix.patch
Patch255: bz459459--CPUFREQ-Fix-format-string-bug.patch
Patch256: ftrace-notrace-exit-init.patch
Patch257: bz458016--random32-seeding_improvement_mrg_2.patch
Patch258: bz461130--CVE-2008-3915--nfsd-fix_buffer_overrun_decoding_NFSv4_acl.patch
Patch259: bz459956--CVE-2008-3792--sctp-fix_potential_panics_in_the_SCTP-AUTH_API.patch
Patch260: bz460094--CVE-2008-3526--sctp_setsockopt_auth_key_integer_overflow.patch
Patch261: bz460395--CVE-2008-4445--sctp_fix_random_memory_dereference_with_SCTP_HMAC_IDENT.patch
Patch262: bz459942--0001-nf_nat-use-secure_ipv4_port_ephemeral-for-NAT-por.patch
Patch263: bz457027--ide-cd-fix_oops_when_using_growisofs_mrg_2.patch
Patch264: bz458350--cifs_asn1_comparison_always_false_2.patch
Patch265: futex-fifo-warn-sysctl.patch
Patch266: lockdep-debug-type-fix.patch
Patch267: seqlock-serialize-against-writers.patch
Patch268: seqlocks-handle-rwlock-and-spin.patch
Patch269: remove_hardcoded_value_of_MAX_RT_PRIO.patch
Patch270: rtmutex-debug-magic.patch
Patch271: qla-mbx-compat-cast.patch
Patch272: add-ibm-himalaya-system-to-ioapic-quirk.patch
### -82
Patch273: bz462282--netlink--fix_overrun_in_attribute_iteration.patch
Patch274: bz461330--lpfc-8.2.2-to-8.2.0.29.diff
### -83
Patch275: bz464507--CVE-2008-3831--i915_kernel_drm_driver_arbitrary_ioremap.patch
Patch276: select_v2--1of5--introduce_a_hrtimeout_function.patch
Patch277: select_v2--2of5--add_a_timespec_add_safe_function.patch
Patch278: select_v2--3of5--add_poll_select_set_timeout_and_poll_select_copy_remaining_helpers.patch
Patch279: select_v2--4of5--add_a_poll_specific_struct_to_the_restart_block_union.patch
Patch280: select_v2--5of5--switch_select_and_poll_over_to_hrtimers.patch

### -84
Patch281: e1000e--write_protect_ICHx_NVM_to_prevent_malicious_write_erase.patch
Patch282: e1000e--implement_FLAG_IS_ICH.patch
Patch283: bnx2_v1_78_backport.patch

### -85
Patch284: bz465745--rtc-fix_kernel_panic_on_second_use_of_SIGIO_nofitication.patch
Patch285: bz465731--sctp-kernel_panic_in_protocol_violation_parameter.patch
Patch286: bz465862--ib-fix-locking-order.patch
Patch287: bz465862-rwlock-handle-bad-locking-practices.patch
Patch288: bz465862-rwlock-update-torture-test.patch
Patch289: bz466708-avoid-splice-with-O_APPEND.patch

### -86
Patch290: bz466341--mm-make_mem_map_allocation_continuous.patch

### -87
Patch291: bz466557-backport_e1000e_from_2.6.26.6.patch
Patch292: bz466558-backport_tg3_from_2.6.26.6.patch
Patch293: bz466568-cxgb3_v1.1.0-ko-a02d44a02bd2b3f3848f30e335adc3c076b3f905_backport.patch

### -88
Patch294: bz467739-ibm-add-strict-st-functions.patch
Patch295: bz467739-ibm-add-amd64_edac-driver
Patch296: bz467739-ibm-allow-rev-f-amd64_edac-to-work.patch
Patch297: ftrace-remove-compat-strict-st-functions.patch
Patch298: net-link-workaround-silly-yield.patch
Patch301: ibm-buffer_io_fix.patch
Patch302: ibm-scsi_dh-add.patch
Patch303: ibm-scsi_dh-add-lsi.patch
Patch304: ibm-scsi_dh-use_in_dmmp.patch
Patch305: ibm-scsi_dh-single_path_init.patch
Patch306: ibm-scsi_dh-remove_dm_pg_init_complete.patch
Patch307: ibm-scsi_dh-remove_dm_hw_support.patch
Patch308: ibm-scsi_dh-remove_dm_hw_handlers.patch
Patch309: ibm-scsi_dh-path_failover.patch
Patch310: ftrace-backport-wrong-address-updates.patch
Patch311: ftrace-update-record-mcount.patch
Patch312: bz466571--sfc_v2.2-31b760202a0911384fa07796df9d1905e9e89a7f_backport.patch
Patch313: bz455095-event-tracer-fix-function-annotations.patch
Patch314: bz455095-event-tracer-i386-fix.patch
Patch315: linux-2.6-scsi-qla2xxx-rediscovering-luns-takes-5-min.patch
Patch316: linux-2.6-scsi-qla2xxx-fix-for-infinite-login-retry.patch
Patch317: linux-2.6-net-qla2xxx-wait-for-flash-to-complete-write.patch
Patch318: linux-2.6-scsi-qla2xxx-add-isp84xx-support.patch
Patch319: linux-2.6-scsi-qla2xxx-additional-residual-count-correction.patch
Patch320: linux-2.6-scsi-qla2xxx-add-more-statistics.patch
Patch321: linux-2.6-scsi-qla2xxx-update-8-02-00-k5-to-8-02-00-k6.patch
Patch322: linux-2.6-scsi-qla2xxx-use-rport-dev-loss-timeout-consistently.patch
Patch323: linux-2.6-scsi-qla2xxx-update-version-for-mrg-1.1.patch
Patch324: linux-2.6-scsi-qla2xxx-firmware-updates-20081021.patch
Patch325: ibm-qla_nomsi.patch
Patch326: linux-2.6-net-add-bnx2x-driver-backport.patch
Patch327: bz466564--ixgbe-1.3.30-k2-5dd2d3322836036da169904afcb7d0f6dff5363f_backport.patch

### -89
Patch328: bz466563-backported-ixgb-from-2.6.27.patch
# Patches from 2.6.24-rt20
# clockevents/hpet
Patch329: 7c1e76897492d92b6a1c2d6892494d39ded9680c.patch
Patch330: d4496b39559c6d43f83e4c08b899984f8b8089b5.patch
Patch331: 7205656ab48da29a95d7f55e43a81db755d3cb3a.patch
Patch332: 9c17bcda991000351cb2373f78be7e4b1c44caa3.patch
Patch333: 1fb9b7d29d8e85ba3196eaa7ab871bf76fc98d36.patch
Patch334: 7cfb0435330364f90f274a26ecdc5f47f738498c.patch
Patch335: 7300711e8c6824fcfbd42a126980ff50439d8dd0.patch
Patch336: 7300711e8c6824fcfbd42a126980ff50439d8dd0-fix.patch
Patch337: f7676254f179eac6b5244a80195ec8ae0e9d4606.patch
Patch338: 72d43d9bc9210d24d09202eaf219eac09e17b339.patch
Patch339: 4ff4b9e19a80b73959ebeb28d1df40176686f0a8.patch
Patch340: 61c22c34c6f80a8e89cff5ff717627c54cc14fd4.patch
# RTC deadlock
Patch341: 38c052f8cff1bd323ccfa968136a9556652ee420.patch
# igb driver backport
Patch342: bz466569--igb-421e02f0e9c3335028750ee411e5534dab82efbd_backport.patch

### -90
Patch343: bz456577_CVE-2008-3528_ext2_bd39597cbd42a784105a04010100e27267481c67.patch
Patch344: bz456577_CVE-2008-3528_ext3_cdbf6dba28e8e6268c8420857696309470009fd9.patch
Patch345: bz456577_CVE-2008-3528_ext4_9d9f177572d9e4eba0f2e18523b44f90dd51fe74.patch
Patch346: bz458797_001_c1d171a002942ea2d93b4fbd0c9583c56fce0772.patch
Patch347: bz458797_002_cc503c1b43e002e3f1fed70f46d947e2bf349bb6.patch
Patch348: bz458797_003_bb1ad8205be4cb95e3286d7442596da6fd70409f.patch
Patch349: bz458797_004_954683a2c19696114894384e34f858bb9f455b11.patch
Patch350: bz458797_005_32a932332c8bad842804842eaf9651ad6268e637.patch
Patch351: bz458797_006_1ec7fd50ba4f845d1cf6b67acabd774577ef13b6.patch
Patch352: bz460102_3051e41ab7daaa59d4564f20b25dcb8c03f35f2b_mrg.patch
Patch353: bz466080_add52379dde2e5300e2d574b172e62c6cf43b3d3.patch
Patch354: bz459505_CVE-2008-0598_001_1129585a08baf58582c0da91e572cb29e3179acf.patch
Patch355: bz459505_CVE-2008-0598_002_ad2fc2cd925300b8127cf682f5a1c7511ae9dd27.patch
Patch356: bz459505_CVE-2008-0598_003_27cb0a75ba252ea7294d67232c4bbbac3f2b2656.patch
Patch357: bz459505_CVE-2008-0598_004_afd962a9e8708c571c5c0c4a6d098f931742c229.patch

### -91
Patch358: posix-timers-race-condition.patch
Patch359: lockdep_make_double_unlock_balance_inline.patch
Patch360: bz460217-nagle-tunables.patch

### -92
Patch361: bz470429-unix_sockets_kernel_panic.patch

### -93
Patch362: bz470429-unix_sockets_kernel_panic-part2.patch

### -94
Patch363: bz471845-rhel5_tvaudio_array_limit.patch
Patch364: bz470762-48735d8d8bd701b1e0cd3d49c21e5e385ddcb077-libertas_fix_buffer_overrun.patch
Patch365: bz470759-3318a386e4ca68c76e0294363d29bdc46fcad670-clear_file_caps.patch

### -95
Patch366: posix-timers-race-condition_2.patch
#Patch367: 001_adjtimex_ee9851b218b8bafa22942b5404505ff3d2d34324.patch
#Patch368: 002_adjtimex_eea83d896e318bda54be2d2770d2c5d6668d11db.patch
#Patch369: 003_adjtimex_916c7a855174e3b53d182b97a26b2e27a29726a1.patch
#Patch370: 004_adjtimex_d40e944c25fb4642adb2a4c580a48218a9f3f824.patch

### -96
Patch371: bz474683-event-tracer-fix-param-offset.patch
Patch372: bz465837-rtc-compat-rhel5.patch
#Patch373: 005_adjtimex_10a398d04c4a1fc395840f4d040493375f562302.patch
#Patch374: 006_adjtimex_max_fix.patch

### -97
# Pick patches from 2.6.24.7-rt25
Patch375: ftrace-fix-preempt-trace-fix.patch
Patch376: rwlock-fix-owners-race.patch
Patch377: rtmutex-fix-rwlock-boosting.patch
Patch378: rtmutex-force-rw-slowpath.patch
Patch379: rtmutex-tglx-is-a-moron.patch
Patch380: tglx-01-ftrace-fix-task-state-print.patch
Patch381: tglx-02-sched-remove-useless-nointeractive-state.patch
Patch382: tglx-03-rtmutex-remove-unused-variable.patch
Patch383: tglx-04-rtmutex-unify-state-manipulation.patch
Patch384: tglx-05-rtmutex-remove-uber-optimization.patch
Patch385: tglx-06-rtmutex-remove-useless-schedule-enforcement.patch
Patch386: tglx-07-rtmutex-prevent-missed-wakeups.patch

### -98
Patch387: bz478802-sctp-memory-overflow-on-bad-FWD-TSN.patch
Patch388: bz472327_CVE-2008-5182_inotify_watch_removal-umount_races.patch
Patch389: ibm-dm-hang-fix.patch
Patch390: ibm-scsi_dh-path_failover_null-dref-fix.patch
Patch391: ibm-scsi_dh-put.patch

### -99
Patch392: bz473697_CVE-2008-5079_atm_module_DoS.patch
Patch393: bz473263_CVE-2008-5300_socket-gc-OOM.patch
Patch394: bz475407_CVE-2008-5700_enforce-a-minimum-SG_IO-timeout.patch
# patches from 2.6.24.7-rt26
Patch395: tracer-fix-clock-backwards.patch
Patch396: irq-tracer-fix.patch
# Other patches
Patch397: lockdep_make_double_unlock_balance_inline-r2.patch
Patch398: add_smi_detector_module.patch

### -100
Patch399: latencytop-f3b8436ad9a8ad36b3c9fa1fe030c7f38e5d3d0b.patch
#Patch400: 007_adjtimex_offset_fixes.patch

### -101
Patch401: ibm-qla_isr_underflow.patch
#Patch402: 008_adjtimex_ntp_offset_precision.patch
Patch403: 001-tsc-tsc_sync-update-tests.patch
Patch404: 002-tsc-update-tsc-stability-tests.patch

### -102
# new adjtimex patch, from jstultz, replacing the 8 old ones.
Patch405: bz472277-adjtimex-fixes.patch
Patch406: smi_detector-kconfig-entry.patch
Patch407: bz472277-adjtimex-fixes-2.patch
Patch408: net-link-workaround-silly-yield-2.patch
Patch409: smi_detector_enhancements.patch

### -103
# Patches from 2.6.24.7-rt27
Patch410: ftrace-correctly-display-preempt-count-in-ftracer.patch
Patch411: 02-hrtimer-prevent-negative-expiry.patch
Patch412: 04-x86-remove-redundant-local-irq-enable.patch
Patch413: 05-trace-warn-if-irqs-enabled-irqs-off.patch
Patch414: sched-fix-the-cpuprio-count-really.patch
Patch415: bz485428-fix_for_ls21_hpet_boot_hang.patch
Patch416: fix_hpet_timer_reinit_for_x86_64.patch

### -104
Patch417: bz486645-fix_nfs_wb_page_to_always_exit_with_an_error_or_a_clean_page.patch

### -105
Patch418: ntp_apply_adjtimex_frequency_tick_changes_immediately.patch
Patch419: bz487382-fix-timeouts-in-sys_pselect7.patch

### -106
Patch420: bz486535-CVE-2009-0675-skfp_ioctl-inverted-logic.patch
Patch421: bz481605-CVE-2009-0269-ecryptfs-readlink-flaw.patch
Patch422: bz482937-CVE-2009-0322-dell_rbu-local-oops.patch
Patch423: bz486514-CVE-2009-0676-memory-disclosure-in-SO_BSDCOMPAT-gsopt.patch
Patch424: bz480599-CVE-2009-0031-missing-kfree-in-keyctl_join_session_keyring.patch
# Patch425: bz479957-CVE-2009-0028-fork-signal-handling-vulnerability.patch

### -107
# removed patch for CVE-2009-0028 from -106

### -108
Patch425: bz486514-CVE-2009-0676-memory-disclosure-in-SO_BSDCOMPAT-gsopt_002.patch


# END OF PATCH DEFINITIONS

Patch10000: linux-2.6-build-nonintconfig.patch

# empty final patch file to facilitate testing of kernel patches
Patch99999: linux-kernel-test.patch

BuildRoot: %{_tmppath}/%{name}-%{KVERREL}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
%global _use_internal_dependency_generator 0
%define __find_provides %_sourcedir/find-provides %{_tmppath}
%define __find_requires /usr/lib/rpm/redhat/find-requires kernel

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%package devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-rt-devel-%{_target_cpu} = %{rpmversion}-%{pkg_release}
Prereq: /usr/bin/find

%description devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.


%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.

%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46

%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package vanilla
Summary: The vanilla upstream kernel the -rt kernel is based on

Group: System Environment/Kernel
Provides: kernel = %{rpmversion}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}vanilla
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes

%description vanilla
This package includes a vanilla version of the Linux kernel. It is
useful for those who dont want a real-time kernel, or who'd like to
quickly check whether a problem seen on -rt is also present in the
vanilla kernel.

%package trace
Summary: The realtime kernel with tracing options turned on

Group: System Environment/Kernel
Provides: kernel = %{rpmversion}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}trace
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReq: no
AutoProv: yes

%description trace
This package includes a version of the realtime Linux kernel with tracing
options compiled turned on and compield in. It is useful in tracking down
latency hot-spots in kernel code.


%package trace-devel
Summary: Development package for building kernel modules to match the tracing kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-rt-trace-devel-%{_target_cpu} = %{rpmversion}-%{pkg_release}
Provides: kernel-rt-trace-devel = %{rpmversion}-%{pkg_release}trace
Prereq: /usr/bin/find

%description trace-devel
This package provides kernel headers and makefiles sufficient to build modules
against the tracing kernel package.


%package vanilla-devel
Summary: Development package for building kernel modules to match the vanilla kernel.
Group: System Environment/Kernel
Provides: kernel-rt-vanilla-devel-%{_target_cpu} = %{rpmversion}-%{pkg_release}
Provides: kernel-rt-vanilla-devel-%{_target_cpu} = %{rpmversion}-%{pkg_release}vanilla
Provides: kernel-rt-vanilla-devel = %{rpmversion}-%{pkg_release}vanilla
AutoReqProv: no
Prereq: /usr/bin/find

%description vanilla-devel
This package provides kernel headers and makefiles sufficient to build modules
against the vanilla kernal package.

%package debug
Summary: A debug realtime kernel and modules
Group: System Environment/Kernel
License: GPLv2
Provides: kernel-rt-debug = %{rpmversion}
Provides: kernel-rt-debug-drm = 4.3.0
Provides: kernel-rt-debug-%{_target_cpu} = %{rpmversion}-%{pkg_release}debug
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
AutoReq: no
AutoProv: yes

%description debug
This package contains the realtime kernel and modules compiled with various
tracing and debugging options enabled. It is primarily useful for tracking
down problem discovered with the regular realtime kernel.

%package debug-devel
Summary: Development package for building kernel modules to match the debug realtime kernel.
Group: System Environment/Kernel
Provides: kernel-rt-debug-devel-%{_target_cpu} = %{rpmversion}-%{pkg_release}
Provides: kernel-rt-debug-devel-%{_target_cpu} = %{rpmversion}-%{pkg_release}debug
Provides: kernel-rt-debug-devel = %{rpmversion}-%{pkg_release}debug
AutoReqProv: no
Prereq: /usr/bin/find

%description debug-devel
This package provides kernel headers and makefiles sufficient to build modules
against the debug kernel-rt package.


%prep
patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    echo "Can't find $RPM_SOURCE_DIR/$patch"
    exit 1;
  fi
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# First we unpack the kernel tarball.
# If this isn't the first make prep, we use links to the existing clean tarball
# which speeds things up quite a bit.

# Update to latest upstream.
%if 0%{?released_kernel}
%define vanillaversion 2.6.%{base_sublevel}
# released_kernel with stable_update available case
%if 0%{?stable_update}
%define vanillaversion 2.6.%{base_sublevel}.%{stable_update}
%endif
# non-released_kernel case
%else
%if 0%{?rcrev}
%define vanillaversion 2.6.%{upstream_sublevel}-rc%{rcrev}
%if 0%{?gitrev}
%define vanillaversion 2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
%define vanillaversion 2.6.%{base_sublevel}-git%{gitrev}
%endif
%endif
%endif

if [ ! -d %{name}-%{rpmversion}-%{pkg_release}/vanilla-%{vanillaversion} ]; then
  # Ok, first time we do a make prep.
  rm -f pax_global_header
%setup -q -n %{name}-%{rpmversion}-%{pkg_release} -c
  mv linux-%{kversion} vanilla-%{vanillaversion}
  cd vanilla-%{vanillaversion}

# Update vanilla to the latest upstream.
# released_kernel with stable_update available case
%if 0%{?stable_update}
  ApplyPatch patch-2.6.%{base_sublevel}.%{stable_update}.bz2
# non-released_kernel case
%else
%if 0%{?rcrev}
  ApplyPatch patch-2.6.%{upstream_sublevel}-rc%{rcrev}.bz2
%if 0%{?gitrev}
  ApplyPatch patch-2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}.bz2
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
  ApplyPatch patch-2.6.%{base_sublevel}-git%{gitrev}.bz2
%endif
%endif
%endif

# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
  ApplyPatch linux-2.6-build-nonintconfig.patch

# create a directory to hold the config files
  mkdir configs

# now move back up and get ready to work
  cd ..

else
  # We already have a vanilla dir.
  cd %{name}-%{rpmversion}-%{pkg_release}
  if [ -d linux-%{rpmversion}.%{_target_cpu} ]; then
     # Just in case we ctrl-c'd a prep already
     rm -rf deleteme.%{_target_cpu}
     # Move away the stale away, and delete in background.
     mv linux-%{rpmversion}.%{_target_cpu} deleteme.%{_target_cpu}
     rm -rf deleteme.%{_target_cpu} &
  fi
fi

cp -rl vanilla-%{vanillaversion} linux-%{rpmversion}.%{_target_cpu}

cd linux-%{rpmversion}.%{_target_cpu}

cp $RPM_SOURCE_DIR/config-* .
cp %{SOURCE15} .

# Dynamically generate kernel .config files from config-* files
make -f %{SOURCE2} VERSION=%{rpmversion} configs

# START OF PATCH APPLICATIONS
ApplyPatch patch-2.6.24.7-rt14.bz2
ApplyPatch linux-2.6-dynticks-off-by-default.patch
ApplyPatch ibm-rmem-for-rtsj.patch
ApplyPatch aic94xx-inline-fw-rt.patch
ApplyPatch qla2xxx-inline-fw-rt.patch
ApplyPatch megaraid_sas.patch
ApplyPatch raw-spinlocks-for-nmi-print.patch
ApplyPatch linux-2.6-rt-oomkill.patch
ApplyPatch limit-i386-ram-to-16gb.patch
ApplyPatch RT-die.patch
ApplyPatch pci-nommconf-noseg.patch
ApplyPatch bz235099-idle-load-fix.patch
ApplyPatch RHEL-RT_AMD_TSC_sync_PN.patch
ApplyPatch RHEL5.1_fix_tscsync.patch
ApplyPatch linux-2.6-rt-quirky-ioapic-legacy-mask-unmask-workaround-jcm.patch
ApplyPatch preempt-irqs-x86-64-ioapic-mask-quirk-jcm.patch
ApplyPatch linux-2.6-vmsplice-fix.patch
ApplyPatch quiet-plit-warning.patch
ApplyPatch fix_misplaced_mb.patch
ApplyPatch linux-2.6.9-bonding-fix-stats-race.patch
ApplyPatch ofed-1.3.patch
ApplyPatch ofed-1.3-rt-compat.patch
ApplyPatch netxen_irq_and_napi.patch
ApplyPatch add-systems-to-ioapic-quirk.patch
ApplyPatch ibm-rtl-driver.patch
ApplyPatch ibm-amd-edac-rh-v1.patch
ApplyPatch ibm-refactor-opstate-RH-v1.patch
ApplyPatch ibm-hs21-tmid-fix.patch
ApplyPatch x86_fix_vsyscall_wreckage.patch
ApplyPatch 0001-x86-fix-32-bit-FRAME_POINTER-chasing-code.patch
ApplyPatch 0002-x86-add-the-capability-to-print-fuzzy-backtraces.patch
ApplyPatch 0003-x86-improve-the-32-bit-Frame-Pointer-backtracer-to.patch
ApplyPatch 0004-x86-pull-bp-calculation-earlier-into-the-backtrace.patch
ApplyPatch 0005-x86-turn-64-bit-x86-HANDLE_STACK-into-print_context.patch
ApplyPatch 0006-x86-use-the-stack-frames-to-get-exact-stack-traces.patch
ApplyPatch 0007-x86-add-a-simple-backtrace-test-module.patch
ApplyPatch 0008-x86-add-the-print-code-before-the-trapping-instruc.patch
ApplyPatch 0009-x86-make-printk_address-regs-ip-always-reliable.patch
ApplyPatch ioapic_quirk_i386-v2.patch
ApplyPatch vsyscall64_dummy_proc_entry.patch
ApplyPatch hrtimer-20080427.patch
ApplyPatch hrtimer-deadlock-fix.patch
ApplyPatch hrtimer-infinite-loop-fix.patch
ApplyPatch tsc-sync-fix.patch
ApplyPatch linux-2.6.24-pollfix.patch
ApplyPatch solarflare.patch
ApplyPatch fix_lock_inversion_in_direct_io.patch
ApplyPatch fix_journal_overflow_issues.patch
ApplyPatch marker-stap-interface-for-MRG.patch
ApplyPatch fix_kdump_crash_kernel_boot_memory_reservation_for_NUMA_machine.patch

# Security Fixes
ApplyPatch CVE-2007-6694--ppc-chrs-null-fix.patch
ApplyPatch CVE-2008-1615--linux-2.6-paranoid-iret.patch
ApplyPatch CVE-2008-1673--ans1_sanity_check_on_BER_decoding.patch
ApplyPatch CVE-2008-2136--missing_kfree_skb_on_pskb_may_pull.patch
# The patch below is for the WRONG CVE (BZ entries confusion)
ApplyPatch CVE-2008-2148--simplify_sched_fair.patch
ApplyPatch CVE-2007-6282--2.6.24.1_esp_iv_bug.patch
ApplyPatch sctp-fix_sctp_addr_overflow.patch

# New Patches
ApplyPatch x86_64--ia32_syscall_restart_fix.patch
ApplyPatch x86_64--ptrace_sign_extend_orig_rax_to_64bits.patch
ApplyPatch hotplug-slab.patch
ApplyPatch hotplug-page_alloc.patch
ApplyPatch hotplug-smp-bootstrap.patch
ApplyPatch hotplug-rcu.patch
ApplyPatch hotplug-idle_task_exit.patch
ApplyPatch hotplug-idle_task_exit_fix.patch
ApplyPatch mm--fix_race_in_COW_logic.patch
ApplyPatch rt_mutex-lock-underflow-fix.patch
ApplyPatch hrtimer-dont-migrate-raisesoftirq.patch
ApplyPatch fix_inotify_user_coalescing-bz453990.patch
ApplyPatch enqueue_task_flags.patch
ApplyPatch futex-bitset-backport.patch 
ApplyPatch ppc64-fix_preempt_unsafe_access_to_per_cpu_variables.patch
ApplyPatch fix_sys_sched_rr_get_interval_slice_for_SCHED_FIFO_tasks.patch
# This is the patch for the real CVE-2008-2148
ApplyPatch CVE-2008-2148--fix_utimensat_permissions_check.patch
ApplyPatch CVE-2008-2372--reinstate_ZERO_PAGE_optimization_in_get_user_pages_and_fix_XIP.patch 
ApplyPatch CVE-2008-2372--fix_ZERO_PAGE_breakage_with_vmware.patch
ApplyPatch ftrace-fix-call-function-pointer.patch
ApplyPatch rwlock-be_more_conservative_in_locking_reader_lock_count.patch
ApplyPatch alloc_stack_early.patch

# Patches from -rt17
ApplyPatch cpu-hotplug-fix-fix-fix.patch
ApplyPatch x86-64-fix-compile.patch
ApplyPatch trace-ktime-scalar.patch
ApplyPatch nfs-stats-miss-preemption.patch
ApplyPatch sched-fix-dequeued-race.patch
ApplyPatch trace-do-not-wakeup-when-irqs-disabled.patch
ApplyPatch acpi-fix-enter-c1.patch
ApplyPatch idle-fix.patch
ApplyPatch powerpc-xics-move-the-call-to-irq-radix-revmap-from-xics-startup-to-xics-host-map.patch
ApplyPatch powerpc-make-the-irq-reverse-mapping-radix-tree-lockless.patch
ApplyPatch cpu-hotplug-cpu-down-vs-preempt-rt_fix.patch
ApplyPatch fix-a-previously-reverted-fix.patch
ApplyPatch nommu-fix-build.patch
ApplyPatch pmtmr-override.patch

# Patches for -76 (mostly Bugs reported from Eugene)
ApplyPatch bz457012--ipv6-use_timer_pending_mrg.patch
ApplyPatch bz457014--pppoe-check_packet_length_on_all_receive_paths.patch
ApplyPatch bz457019--pppoe-unshare_skb_before_anything_else_mrg.patch
ApplyPatch bz457027--ide-cd-fix_oops_when_using_growisofs_mrg.patch
ApplyPatch bz457507--tmpfs-fix_kernel_BUG_in_shmem_delete_inode.patch
ApplyPatch bz457705--fix_off-by-one_error_in_iov_iter_advance.patch
ApplyPatch bz457858--CVE-2008-3275-Linux_kernel_local_filesystem_DoS.patch
ApplyPatch bz457995--CVE-2008-3272-snd_seq_oss_synth_make_info_leak.patch
ApplyPatch linux-2.6-panic-on-oops.patch
ApplyPatch bz458016--random32-seeding_improvement_mrg.patch
ApplyPatch bz458340--parse_pmtmr-stores_ulong_in_u32.patch
ApplyPatch clean_-75_compile_warning.patch
ApplyPatch bz458350--cifs_asn1_comparison_always_false.patch
ApplyPatch bz458755--dlm-fix-possible-use-after-free.patch
ApplyPatch bz458756--dlm-check-for-null-in-device_write.patch
ApplyPatch bz458758--dlm-dlm-user.c-input-validation-fixes.patch
ApplyPatch rename_cpu_posix_timer.patch
ApplyPatch bz448574-increase-max-stack-trace-entries.patch
ApplyPatch 0001-lockdep-fix-combinatorial-explosion-in-lock-subgrap.patch
ApplyPatch 0001-lockdep-build-fix.patch
ApplyPatch 0002-lockdep-change-scheduler-annotation.patch
ApplyPatch 0004-lockdep-re-annotate-scheduler-runqueues.patch
ApplyPatch bz459141--ftrace-mcount-record-big.patch
ApplyPatch bz457507--CVE-2008-3534--fbdefio-add-set_page_dirty-handler-to-deferred-IO-FB.patch 
ApplyPatch bz459231--CVE-2008-3276--Linux_kernel_dccp_setsockopt_change.patch
ApplyPatch bz459462--binfmt_misc.c--avoid_potential_kernel_stack.patch
ApplyPatch bz459462--binfmt_misc.c--avoid_potential_kernel_stack_fix.patch
ApplyPatch bz459459--CPUFREQ-Fix-format-string-bug.patch
ApplyPatch ftrace-notrace-exit-init.patch
ApplyPatch bz458016--random32-seeding_improvement_mrg_2.patch
ApplyPatch bz461130--CVE-2008-3915--nfsd-fix_buffer_overrun_decoding_NFSv4_acl.patch
ApplyPatch bz459956--CVE-2008-3792--sctp-fix_potential_panics_in_the_SCTP-AUTH_API.patch
ApplyPatch bz460094--CVE-2008-3526--sctp_setsockopt_auth_key_integer_overflow.patch
ApplyPatch bz460395--CVE-2008-4445--sctp_fix_random_memory_dereference_with_SCTP_HMAC_IDENT.patch
ApplyPatch bz459942--0001-nf_nat-use-secure_ipv4_port_ephemeral-for-NAT-por.patch
ApplyPatch bz457027--ide-cd-fix_oops_when_using_growisofs_mrg_2.patch
ApplyPatch bz458350--cifs_asn1_comparison_always_false_2.patch
ApplyPatch futex-fifo-warn-sysctl.patch
ApplyPatch lockdep-debug-type-fix.patch
ApplyPatch seqlock-serialize-against-writers.patch
ApplyPatch seqlocks-handle-rwlock-and-spin.patch
ApplyPatch remove_hardcoded_value_of_MAX_RT_PRIO.patch
ApplyPatch rtmutex-debug-magic.patch
ApplyPatch qla-mbx-compat-cast.patch
ApplyPatch add-ibm-himalaya-system-to-ioapic-quirk.patch
### -82
ApplyPatch bz462282--netlink--fix_overrun_in_attribute_iteration.patch
ApplyPatch bz461330--lpfc-8.2.2-to-8.2.0.29.diff
### -83
ApplyPatch bz464507--CVE-2008-3831--i915_kernel_drm_driver_arbitrary_ioremap.patch
ApplyPatch select_v2--1of5--introduce_a_hrtimeout_function.patch
ApplyPatch select_v2--2of5--add_a_timespec_add_safe_function.patch
ApplyPatch select_v2--3of5--add_poll_select_set_timeout_and_poll_select_copy_remaining_helpers.patch
ApplyPatch select_v2--4of5--add_a_poll_specific_struct_to_the_restart_block_union.patch
ApplyPatch select_v2--5of5--switch_select_and_poll_over_to_hrtimers.patch
### -84
ApplyPatch e1000e--write_protect_ICHx_NVM_to_prevent_malicious_write_erase.patch
ApplyPatch e1000e--implement_FLAG_IS_ICH.patch
ApplyPatch bnx2_v1_78_backport.patch

### -85
ApplyPatch bz465745--rtc-fix_kernel_panic_on_second_use_of_SIGIO_nofitication.patch
ApplyPatch bz465731--sctp-kernel_panic_in_protocol_violation_parameter.patch
ApplyPatch bz465862--ib-fix-locking-order.patch
ApplyPatch bz465862-rwlock-handle-bad-locking-practices.patch
ApplyPatch bz465862-rwlock-update-torture-test.patch
ApplyPatch bz466708-avoid-splice-with-O_APPEND.patch

### -86
ApplyPatch bz466341--mm-make_mem_map_allocation_continuous.patch

### -87
ApplyPatch bz466557-backport_e1000e_from_2.6.26.6.patch
ApplyPatch bz466558-backport_tg3_from_2.6.26.6.patch
ApplyPatch bz466568-cxgb3_v1.1.0-ko-a02d44a02bd2b3f3848f30e335adc3c076b3f905_backport.patch

### -88
ApplyPatch bz467739-ibm-add-strict-st-functions.patch
ApplyPatch bz467739-ibm-add-amd64_edac-driver
ApplyPatch bz467739-ibm-allow-rev-f-amd64_edac-to-work.patch
ApplyPatch ftrace-remove-compat-strict-st-functions.patch
ApplyPatch net-link-workaround-silly-yield.patch
ApplyPatch ibm-buffer_io_fix.patch
ApplyPatch ftrace-backport-wrong-address-updates.patch
ApplyPatch ftrace-update-record-mcount.patch
ApplyPatch bz466571--sfc_v2.2-31b760202a0911384fa07796df9d1905e9e89a7f_backport.patch
ApplyPatch bz455095-event-tracer-fix-function-annotations.patch
ApplyPatch bz455095-event-tracer-i386-fix.patch
ApplyPatch linux-2.6-scsi-qla2xxx-rediscovering-luns-takes-5-min.patch
ApplyPatch linux-2.6-scsi-qla2xxx-fix-for-infinite-login-retry.patch
ApplyPatch linux-2.6-net-qla2xxx-wait-for-flash-to-complete-write.patch
ApplyPatch linux-2.6-scsi-qla2xxx-add-isp84xx-support.patch
ApplyPatch linux-2.6-scsi-qla2xxx-additional-residual-count-correction.patch
ApplyPatch linux-2.6-scsi-qla2xxx-add-more-statistics.patch
ApplyPatch linux-2.6-scsi-qla2xxx-update-8-02-00-k5-to-8-02-00-k6.patch
ApplyPatch linux-2.6-scsi-qla2xxx-use-rport-dev-loss-timeout-consistently.patch
ApplyPatch linux-2.6-scsi-qla2xxx-update-version-for-mrg-1.1.patch
ApplyPatch linux-2.6-scsi-qla2xxx-firmware-updates-20081021.patch
ApplyPatch ibm-qla_nomsi.patch
ApplyPatch linux-2.6-net-add-bnx2x-driver-backport.patch
ApplyPatch bz466564--ixgbe-1.3.30-k2-5dd2d3322836036da169904afcb7d0f6dff5363f_backport.patch

### -89
ApplyPatch bz466563-backported-ixgb-from-2.6.27.patch
# Patches from 2.6.24-rt20
# clockevents/hpet
ApplyPatch 7c1e76897492d92b6a1c2d6892494d39ded9680c.patch
ApplyPatch d4496b39559c6d43f83e4c08b899984f8b8089b5.patch
ApplyPatch 7205656ab48da29a95d7f55e43a81db755d3cb3a.patch
ApplyPatch 9c17bcda991000351cb2373f78be7e4b1c44caa3.patch
ApplyPatch 1fb9b7d29d8e85ba3196eaa7ab871bf76fc98d36.patch
ApplyPatch 7cfb0435330364f90f274a26ecdc5f47f738498c.patch
ApplyPatch 7300711e8c6824fcfbd42a126980ff50439d8dd0.patch
ApplyPatch 7300711e8c6824fcfbd42a126980ff50439d8dd0-fix.patch
ApplyPatch f7676254f179eac6b5244a80195ec8ae0e9d4606.patch
ApplyPatch 72d43d9bc9210d24d09202eaf219eac09e17b339.patch
ApplyPatch 4ff4b9e19a80b73959ebeb28d1df40176686f0a8.patch
ApplyPatch 61c22c34c6f80a8e89cff5ff717627c54cc14fd4.patch
# RTC deadlock
ApplyPatch 38c052f8cff1bd323ccfa968136a9556652ee420.patch
# igb driver backport
ApplyPatch bz466569--igb-421e02f0e9c3335028750ee411e5534dab82efbd_backport.patch
ApplyPatch ibm-scsi_dh-add.patch
ApplyPatch ibm-scsi_dh-add-lsi.patch
ApplyPatch ibm-scsi_dh-use_in_dmmp.patch
ApplyPatch ibm-scsi_dh-single_path_init.patch
ApplyPatch ibm-scsi_dh-remove_dm_pg_init_complete.patch
ApplyPatch ibm-scsi_dh-remove_dm_hw_support.patch
ApplyPatch ibm-scsi_dh-remove_dm_hw_handlers.patch
ApplyPatch ibm-scsi_dh-path_failover.patch

### -90
ApplyPatch bz456577_CVE-2008-3528_ext2_bd39597cbd42a784105a04010100e27267481c67.patch
ApplyPatch bz456577_CVE-2008-3528_ext3_cdbf6dba28e8e6268c8420857696309470009fd9.patch
ApplyPatch bz456577_CVE-2008-3528_ext4_9d9f177572d9e4eba0f2e18523b44f90dd51fe74.patch
ApplyPatch bz458797_001_c1d171a002942ea2d93b4fbd0c9583c56fce0772.patch
ApplyPatch bz458797_002_cc503c1b43e002e3f1fed70f46d947e2bf349bb6.patch
ApplyPatch bz458797_003_bb1ad8205be4cb95e3286d7442596da6fd70409f.patch
ApplyPatch bz458797_004_954683a2c19696114894384e34f858bb9f455b11.patch
ApplyPatch bz458797_005_32a932332c8bad842804842eaf9651ad6268e637.patch
ApplyPatch bz458797_006_1ec7fd50ba4f845d1cf6b67acabd774577ef13b6.patch
ApplyPatch bz460102_3051e41ab7daaa59d4564f20b25dcb8c03f35f2b_mrg.patch
ApplyPatch bz466080_add52379dde2e5300e2d574b172e62c6cf43b3d3.patch
ApplyPatch bz459505_CVE-2008-0598_001_1129585a08baf58582c0da91e572cb29e3179acf.patch
ApplyPatch bz459505_CVE-2008-0598_002_ad2fc2cd925300b8127cf682f5a1c7511ae9dd27.patch
ApplyPatch bz459505_CVE-2008-0598_003_27cb0a75ba252ea7294d67232c4bbbac3f2b2656.patch
ApplyPatch bz459505_CVE-2008-0598_004_afd962a9e8708c571c5c0c4a6d098f931742c229.patch

### -91
ApplyPatch posix-timers-race-condition.patch
ApplyPatch lockdep_make_double_unlock_balance_inline.patch
ApplyPatch bz460217-nagle-tunables.patch

### -92
ApplyPatch bz470429-unix_sockets_kernel_panic.patch

### -93
ApplyPatch bz470429-unix_sockets_kernel_panic-part2.patch

### -94
ApplyPatch bz471845-rhel5_tvaudio_array_limit.patch
ApplyPatch bz470762-48735d8d8bd701b1e0cd3d49c21e5e385ddcb077-libertas_fix_buffer_overrun.patch
ApplyPatch bz470759-3318a386e4ca68c76e0294363d29bdc46fcad670-clear_file_caps.patch

### -95
ApplyPatch posix-timers-race-condition_2.patch
#ApplyPatch 001_adjtimex_ee9851b218b8bafa22942b5404505ff3d2d34324.patch
#ApplyPatch 002_adjtimex_eea83d896e318bda54be2d2770d2c5d6668d11db.patch
#ApplyPatch 003_adjtimex_916c7a855174e3b53d182b97a26b2e27a29726a1.patch
#ApplyPatch 004_adjtimex_d40e944c25fb4642adb2a4c580a48218a9f3f824.patch

### -96
ApplyPatch bz474683-event-tracer-fix-param-offset.patch
ApplyPatch bz465837-rtc-compat-rhel5.patch
#ApplyPatch 005_adjtimex_10a398d04c4a1fc395840f4d040493375f562302.patch
#ApplyPatch 006_adjtimex_max_fix.patch

### -97
# Pick patches from 2.6.24.7-rt25
ApplyPatch ftrace-fix-preempt-trace-fix.patch
ApplyPatch rwlock-fix-owners-race.patch
ApplyPatch rtmutex-fix-rwlock-boosting.patch
ApplyPatch rtmutex-force-rw-slowpath.patch
ApplyPatch rtmutex-tglx-is-a-moron.patch
ApplyPatch tglx-01-ftrace-fix-task-state-print.patch
ApplyPatch tglx-02-sched-remove-useless-nointeractive-state.patch
ApplyPatch tglx-03-rtmutex-remove-unused-variable.patch
ApplyPatch tglx-04-rtmutex-unify-state-manipulation.patch
ApplyPatch tglx-05-rtmutex-remove-uber-optimization.patch
ApplyPatch tglx-06-rtmutex-remove-useless-schedule-enforcement.patch
ApplyPatch tglx-07-rtmutex-prevent-missed-wakeups.patch

### -98
ApplyPatch bz478802-sctp-memory-overflow-on-bad-FWD-TSN.patch
ApplyPatch bz472327_CVE-2008-5182_inotify_watch_removal-umount_races.patch
ApplyPatch ibm-dm-hang-fix.patch
ApplyPatch ibm-scsi_dh-path_failover_null-dref-fix.patch
ApplyPatch ibm-scsi_dh-put.patch

### -99
ApplyPatch bz473697_CVE-2008-5079_atm_module_DoS.patch
ApplyPatch bz473263_CVE-2008-5300_socket-gc-OOM.patch
ApplyPatch bz475407_CVE-2008-5700_enforce-a-minimum-SG_IO-timeout.patch
# patches from 2.6.24.7-rt26
ApplyPatch tracer-fix-clock-backwards.patch
ApplyPatch irq-tracer-fix.patch
# Other patches
ApplyPatch lockdep_make_double_unlock_balance_inline-r2.patch
ApplyPatch add_smi_detector_module.patch

### -100
ApplyPatch latencytop-f3b8436ad9a8ad36b3c9fa1fe030c7f38e5d3d0b.patch
#ApplyPatch 007_adjtimex_offset_fixes.patch

### -101
ApplyPatch ibm-qla_isr_underflow.patch
#ApplyPatch 008_adjtimex_ntp_offset_precision.patch
ApplyPatch 001-tsc-tsc_sync-update-tests.patch
ApplyPatch 002-tsc-update-tsc-stability-tests.patch

### -102
# new adjtimex patch, from jstultz, replacing the 8 old ones.
ApplyPatch bz472277-adjtimex-fixes.patch
ApplyPatch smi_detector-kconfig-entry.patch
ApplyPatch bz472277-adjtimex-fixes-2.patch
ApplyPatch net-link-workaround-silly-yield-2.patch
ApplyPatch smi_detector_enhancements.patch

### -103
# Patches from 2.6.24.7-rt27
ApplyPatch ftrace-correctly-display-preempt-count-in-ftracer.patch
ApplyPatch 02-hrtimer-prevent-negative-expiry.patch
ApplyPatch 04-x86-remove-redundant-local-irq-enable.patch
ApplyPatch 05-trace-warn-if-irqs-enabled-irqs-off.patch
ApplyPatch sched-fix-the-cpuprio-count-really.patch
ApplyPatch bz485428-fix_for_ls21_hpet_boot_hang.patch
ApplyPatch fix_hpet_timer_reinit_for_x86_64.patch

### -104
ApplyPatch bz486645-fix_nfs_wb_page_to_always_exit_with_an_error_or_a_clean_page.patch

### -105
ApplyPatch ntp_apply_adjtimex_frequency_tick_changes_immediately.patch
ApplyPatch bz487382-fix-timeouts-in-sys_pselect7.patch

### -106
ApplyPatch bz486535-CVE-2009-0675-skfp_ioctl-inverted-logic.patch
ApplyPatch bz481605-CVE-2009-0269-ecryptfs-readlink-flaw.patch
ApplyPatch bz482937-CVE-2009-0322-dell_rbu-local-oops.patch
ApplyPatch bz486514-CVE-2009-0676-memory-disclosure-in-SO_BSDCOMPAT-gsopt.patch
ApplyPatch bz480599-CVE-2009-0031-missing-kfree-in-keyctl_join_session_keyring.patch
# ApplyPatch bz479957-CVE-2009-0028-fork-signal-handling-vulnerability.patch

### -107
# removed patch for CVE-2009-0028 from -106

### -108
ApplyPatch bz486514-CVE-2009-0676-memory-disclosure-in-SO_BSDCOMPAT-gsopt_002.patch


# END OF PATCH APPLICATIONS

# empty final patch to facilitate testing of kernel patches
ApplyPatch linux-kernel-test.patch

cp %{SOURCE10} Documentation/

# Necessary for BZ459141 (ftrace daemon removal)
chmod +x scripts/recordmcount.pl

# now run oldconfig over all the config files
for i in *.config
do
  if [ "$i" != ${i//vanilla/chocolate/} ]; then
     isvanilla=true
     OLDDIR=`pwd`
  else
     isvanilla=false
  fi
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  if [ "$isvanilla" = "true" ]; then
    pushd ../vanilla-%{vanillaversion};
    mv $OLDDIR/.config .
  fi
  pwd
  make ARCH=$Arch nonint_oldconfig > /dev/null
  pwd
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
  if [ "$isvanilla" = "true" ]; then
    popd
  fi
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
cd ..
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

###
### build
###
%build
#
# Create gpg keys for signing the modules
#

%if %{signmodules}
gpg --homedir . --batch --gen-key %{SOURCE11}
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub
make linux-%{rpmversion}.%{_target_cpu}/scripts/bin2c
linux-%{rpmversion}.%{_target_cpu}/scripts/bin2c ksign_def_public_key __initdata < extract.pub > linux-%{rpmversion}.%{_target_cpu}/crypto/signature/key.h
%endif

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    DoDevel=$4

    if [ "vanilla" = "$Flavour" ]; then
      pushd ../vanilla-%{vanillaversion}
    fi

    # Pick the right config file for the kernel we're building
    if [ -n "$Flavour" ] ; then
      Config=kernel-%{rpmversion}-%{_target_cpu}-%{realtime}$Flavour.config
      DevelDir=/usr/src/kernels/%{KVERREL}-$Flavour-%{_target_cpu}
      DevelLink=
    else
      Config=kernel-%{rpmversion}-%{_target_cpu}-%{realtime}.config
      DevelDir=/usr/src/kernels/%{KVERREL}-%{_target_cpu}
      DevelLink=
    fi

    KernelVer=%{KVERREL}$Flavour
    echo BUILDING A KERNEL FOR $Flavour %{_target_cpu}...
    echo "KernelVer => $KernelVer"
    echo "_smp_mflags => %{_smp_mflags}"

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = %{?stablerev}-%{pkg_release}$Flavour/" Makefile

    # ensure the sublevel is correct (the upstream sublevel)
    perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{upstream_sublevel}/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    if [ "$KernelImage" == "x86" ]; then
       KernelImage=arch/$Arch/boot/bzImage
    fi

    make -s ARCH=$Arch nonint_oldconfig > /dev/null
    make -s ARCH=$Arch %{?_smp_mflags} $MakeTarget
    make -s ARCH=$Arch %{?_smp_mflags} modules || exit 1

    # Start installing the results

%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    touch $RPM_BUILD_ROOT/boot/initrd-$KernelVer.img
    cp $KernelImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer

%if %{buildkabi}
    # Create the kABI metadata for use in packaging
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    chmod 0755 %_sourcedir/kabitool
    if [ ! -e $RPM_SOURCE_DIR/kabi_whitelist ]; then
        %_sourcedir/kabitool -b $RPM_BUILD_ROOT/$DevelDir -k $KernelVer -l $RPM_BUILD_ROOT/kabi_whitelist
    else
	cp $RPM_SOURCE_DIR/kabi_whitelist $RPM_BUILD_ROOT/kabi_whitelist
    fi
    rm -f %{_tmppath}/kernel-$KernelVer-kabideps
    %_sourcedir/kabitool -b . -d %{_tmppath}/kernel-$KernelVer-kabideps -k $KernelVer -w $RPM_BUILD_ROOT/kabi_whitelist
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    if [ "$DoDevel" = "True" ]
    then
    	rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
	rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
	mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
	(cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
	# dirs for additional modules per module-init-tools, kbuild/modules.txt
    	mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    	mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    	mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    	# first copy everything
    	cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    	cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
%if %{buildkabi}
    	mv $RPM_BUILD_ROOT/kabi_whitelist $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    	cp symsets-$KernelVer.tar.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
%endif
    	# then drop all but the needed Makefiles/Kconfig files
    	rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    	rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    	rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    	cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    	cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    	if [ -d arch/%{_arch}/scripts ]; then
      	  cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    	fi
    	if [ -f arch/%{_arch}/*lds ]; then
    	  cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    	fi
    	rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    	rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    	mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    	cd include
    	cp -a acpi config keys linux math-emu media mtd net pcmcia rdma rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    	cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    	# While arch/powerpc/include/asm is still a symlink to the old
    	# include/asm-ppc{64,} directory, include that in kernel-devel too.
    	if [ "$Arch" = "powerpc" -a -r ../arch/powerpc/include/asm ]; then
    	  cp -a `readlink ../arch/powerpc/include/asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    	  mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
    	  pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
    	  ln -sf ../../../include/asm-ppc* asm
    	  popd
    	fi
    	# Make sure the Makefile and version.h have a matching timestamp so that
    	# external modules can be built
    	touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    	touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    	# Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    	cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    	cd ..

    	#
    	# save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    	#
%if "%{_enable_debug_packages}" == "1"
    	mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    	cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
%endif

    	find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # gpg sign the modules
%if %{signmodules}
    	gcc -o scripts/modsign/mod-extract scripts/modsign/mod-extract.c -Wall
    	KEYFLAGS="--no-default-keyring --homedir .."
    	KEYFLAGS="$KEYFLAGS --secret-keyring ../kernel.sec"
    	KEYFLAGS="$KEYFLAGS --keyring ../kernel.pub"
    	export KEYFLAGS

    	for i in `cat modnames`
    	do
    	  sh ./scripts/modsign/modsign.sh $i Red
    	  mv -f $i.signed $i
    	done
    	unset KEYFLAGS
%endif
    	# mark modules executable so that strip-to-file can strip them
    	cat modnames | xargs chmod u+x

    	# detect missing or incorrect license tags
    	for i in `cat modnames`
    	do
    	  echo -n "$i "
    	  /sbin/modinfo -l $i >> modinfo
    	done
    	cat modinfo |\
    	  grep -v "^GPL" |
    	  grep -v "^Dual BSD/GPL" |\
    	  grep -v "^Dual MPL/GPL" |\
    	  grep -v "^GPL and additional rights" |\
    	  grep -v "^GPL v2" && exit 1
    	rm -f modinfo
    	rm -f modnames
    	# remove files that will be auto generated by depmod at rpm -i time
    	rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*

    	# Move the devel headers out of the root file system
    	mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    	mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    	ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    	[ -z "$DevelLink" ] || ln -sf `basename $DevelDir` $RPM_BUILD_ROOT/$DevelLink
    fi
    if [ "vanilla" = "$Flavour" ]; then
      popd
    fi
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

cd linux-%{rpmversion}.%{_target_cpu}

%if %{buildrt}
BuildKernel %make_target %kernel_image "" True
%endif

%if %{builddebug}
BuildKernel %make_target %kernel_image debug  True
%endif

%if %{buildtrace}
BuildKernel %make_target %kernel_image trace True
%endif

%if %{buildvanilla}
BuildKernel %make_target %kernel_image vanilla True
%endif

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%global __debug_package 1
%package debuginfo-common
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
Provides: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}

%description debuginfo-common
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%files debuginfo-common
%defattr(-,root,root)
/usr/src/debug/%{name}-%{rpmversion}-%{pkg_release}/linux-%{rpmversion}.%{_target_cpu}
/usr/src/debug/.build-id
%if %{buildvanilla}
/usr/src/debug/%{name}-%{rpmversion}-%{pkg_release}/vanilla-%{vanillaversion}
%endif
%dir /usr/src/debug
%dir /usr/lib/debug
%dir /usr/lib/debug/%{image_install_path}
%dir /usr/lib/debug/lib
%dir /usr/lib/debug/lib/modules
%dir /usr/lib/debug/usr/src/kernels
%endif
%endif

###
### install
###

%install

cd linux-%{rpmversion}.%{_target_cpu}

# make the build-id directory (for building on fedora)
mkdir -p $RPM_BUILD_ROOT/usr/src/debug/.build-id

%if %{builddoc}
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{rpmversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{rpmversion}
%endif

%if %{buildheaders}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Manually go through the 'headers_check' process for every file, but
# don't die if it fails
chmod +x scripts/hdrcheck.sh
echo -e '*****\n*****\nHEADER EXPORT WARNINGS:\n*****' > hdrwarnings.txt
for FILE in `find $RPM_BUILD_ROOT/usr/include` ; do
    scripts/hdrcheck.sh $RPM_BUILD_ROOT/usr/include $FILE >> hdrwarnings.txt || :
done
echo -e '*****\n*****' >> hdrwarnings.txt
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif
###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%post
/sbin/new-kernel-pkg --package kernel-rt --banner "Red Hat Enterprise Linux (realtime)" --mkinitrd --depmod --install %{KVERREL} || exit $?

%post devel
if [ -f /etc/sysconfig/kernel ]
then
    . /etc/sysconfig/kernel || exit $?
fi
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post vanilla
/sbin/new-kernel-pkg --package kernel-rt-vanilla --mkinitrd --depmod --install %{KVERREL}vanilla || exit $?

%post trace
/sbin/new-kernel-pkg --package kernel-rt-trace --mkinitrd --depmod --install %{KVERREL}trace || exit $?

%post debug
/sbin/new-kernel-pkg --package kernel-rt --banner "Red Hat Enterprise Linux (realtime debug)" --mkinitrd --depmod --install %{KVERREL}debug || exit $?

%preun
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL} || exit $?

%preun vanilla
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}vanilla || exit $?

%preun trace
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}trace || exit $?

%preun debug
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}debug || exit $?

###
### file lists
###

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

%if %{buildrt}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%global __debug_package 1
%package debuginfo
Summary: Debug information for package %{name}
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-debuginfo-%{_target_cpu} = %{KVERREL}
%description debuginfo
This package provides debug information for package %{name}
This is required to use SystemTap with %{name}-%{KVERREL}.
%files debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}
/usr/lib/debug/usr/src/kernels/%{KVERREL}-%{_target_cpu}
%endif
%endif

%files
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}
/boot/System.map-%{KVERREL}
%if %{buildkabi}
/boot/symvers-%{KVERREL}.gz
%endif
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
/lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source
/lib/modules/%{KVERREL}/extra
/lib/modules/%{KVERREL}/updates
/lib/modules/%{KVERREL}/weak-updates
%ghost /boot/initrd-%{KVERREL}.img


%files devel
%defattr(-,root,root)
/usr/src/kernels/%{KVERREL}-%{_target_cpu}

%endif # buildrt

%if %{buildheaders}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{builddebug}
%files debug
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}debug
/boot/System.map-%{KVERREL}debug
%if %{buildkabi}
/boot/symvers-%{KVERREL}debug.gz
%endif
/boot/config-%{KVERREL}debug
%dir /lib/modules/%{KVERREL}debug
/lib/modules/%{KVERREL}debug/kernel
/lib/modules/%{KVERREL}debug/build
/lib/modules/%{KVERREL}debug/source
/lib/modules/%{KVERREL}debug/extra
/lib/modules/%{KVERREL}debug/updates
/lib/modules/%{KVERREL}debug/weak-updates
%ghost /boot/initrd-%{KVERREL}debug.img

%files debug-devel
%defattr(-,root,root)
/usr/src/kernels/%{KVERREL}-debug-%{_target_cpu}

%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%global __debug_package 1
%package debug-debuginfo
Summary: Debug information for package %{name}-debug
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-debug-debuginfo-%{_target_cpu} = %{KVERREL}
%description debug-debuginfo
This package provides debug information for package %{name}-debug
This is required to use SystemTap with %{name}-debug-%{KVERREL}.
%files debug-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}debug.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}debug
/usr/lib/debug/usr/src/kernels/%{KVERREL}-debug-%{_target_cpu}
%endif
%endif
%endif # builddebug

%if %{buildvanilla}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%global __debug_package 1
%package vanilla-debuginfo
Summary: Debug information for package %{name}-vanilla
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-vanilla-debuginfo-%{_target_cpu} = %{KVERREL}
%description vanilla-debuginfo
This package provides debug information for package %{name}-vanilla
This is required to use SystemTap with %{name}-vanilla-%{KVERREL}.
%files vanilla-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{image_install_path}/*-%{KVERREL}vanilla.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}vanilla
/usr/lib/debug/usr/src/kernels/%{KVERREL}-vanilla-%{_target_cpu}
%endif
%endif

%files vanilla
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}vanilla
/boot/System.map-%{KVERREL}vanilla
%if %{buildkabi}
/boot/symvers-%{KVERREL}vanilla.gz
%endif
/boot/config-%{KVERREL}vanilla
%dir /lib/modules/%{KVERREL}vanilla
/lib/modules/%{KVERREL}vanilla/kernel
/lib/modules/%{KVERREL}vanilla/build
/lib/modules/%{KVERREL}vanilla/source
/lib/modules/%{KVERREL}vanilla/extra
/lib/modules/%{KVERREL}vanilla/updates
/lib/modules/%{KVERREL}vanilla/weak-updates
%ghost /boot/initrd-%{KVERREL}vanilla.img

%files vanilla-devel
%defattr(-,root,root)
/usr/src/kernels/%{KVERREL}-vanilla-%{_target_cpu}
%endif

%if %{buildtrace}
%if "%{_enable_debug_packages}" == "1"
%ifnarch noarch
%global __debug_package 1
%package trace-debuginfo
Summary: Debug information for package %{name}-trace
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{KVERREL}
Provides: %{name}-trace-debuginfo-%{_target_cpu} = %{KVERREL}
%description trace-debuginfo
This package provides debug information for package %{name}-trace
This is required to use SystemTap with %{name}-trace-%{KVERREL}.
%files trace-debuginfo
%defattr(-,root,root)
%if "%{elf_image_install_path}" != ""
/usr/lib/debug/%{elf_image_install_path}/*-%{KVERREL}trace.debug
%endif
/usr/lib/debug/lib/modules/%{KVERREL}trace
/usr/lib/debug/usr/src/kernels/%{KVERREL}-trace-%{_target_cpu}
%endif
%endif

%files trace
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}trace
/boot/System.map-%{KVERREL}trace
%if %{buildkabi}
/boot/symvers-%{KVERREL}trace.gz
%endif
/boot/config-%{KVERREL}trace
%dir /lib/modules/%{KVERREL}trace
/lib/modules/%{KVERREL}trace/kernel
/lib/modules/%{KVERREL}trace/build
/lib/modules/%{KVERREL}trace/source
/lib/modules/%{KVERREL}trace/extra
/lib/modules/%{KVERREL}trace/updates
/lib/modules/%{KVERREL}trace/weak-updates
%ghost /boot/initrd-%{KVERREL}trace.img

%files trace-devel
%defattr(-,root,root)
/usr/src/kernels/%{KVERREL}-trace-%{_target_cpu}
%endif

# only some architecture builds need kernel-doc

%if %{builddoc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}
%endif


%changelog
* Mon Mar 23 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-108
- [net] Added a enhanced patch to SO_BSDCOMPAT gsopt leak [486514] {CVE-2009-0676}

* Tue Mar 03 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-107
- Removed patch for [479957] {CVE-2009-0028}

* Thu Feb 26 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-106
- [fs] ecryptfs readlink flaw [481605] {CVE-2009-0269}
- [net] skfp_ioctl inverted logic flaw [486535] {CVE-2009-0675}
- [drivers] dell_rbu local oops [482937] {CVE-2009-0322}
- [net] memory disclosure in SO_BSDCOMPAT gsopt [486514] {CVE-2009-0676}
- [security] missing kfree in keyctl_join_session_keyring [480599] {CVE-2009-0031}
- [core] fork: signal handling vulnerability [479957] {CVE-2009-0028}

* Fri Feb 20 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-105
- [time] NTP: Apply adjtimex frequency/tick changes immediately (John Stultz)
- [fs] fix handling of NULL timeouts in sys_pselect7 [487382]

* Fri Feb 20 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-104
- [fs] Fix bug in shared page handling over NFS (Jon Masters) [486645]

* Fri Feb 13 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-103
- [time] IBM LS20/LS21 blades fail to boot with HPET enabled in BIOS [485428]
- [time] fix hpet timer reinit for x86_64 
- Patches from 2.6.24.7-rt27:
  - ftrace: display real preempt_count in ftracer
  - hrtimer: prevent negative expiry value after clock_was_set()
  - x86: remove redundant local_irq_enable() in handle_signal()
  - trace: warn if irqs already enabled in irqs_off latency check
  - sched: fix the cpuprio count really

* Thu Feb 05 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-102
- [time] cleaner adjtimex patches replacing old ones (John Stultz) [472277]
- [tools] change smi_detector sample format to decimal
- [tools] smi_detector Kconfig entry and code enhancements (Clark Williams)
- [scsi] enabled CONFIG_SCSI_WAIT_SCAN
- [net] netlink_broadcast calls yield() (Arnaldo Carvalho de Melo) [463207]

* Fri Jan 30 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-101
- [block] remove underflow debug messages flood from SAN boot (jvrao@ibm) [481724]
- [time] fix ntp_update_offset time_offset calculation [478991]
- [time] fixes to tsc stability tests [480244]

* Thu Jan 22 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-100
- [tools] Added the latencytop infrastructure (Arnaldo Carvalho de Melo)
- [time] fail tests 4 and 5 of LTP's adjtimex2 (Luis Goncalves) [478991]

* Fri Jan 16 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-99
- [net] atm module local denial of service (Eugene Teo) [473697] {CVE-2008-5079}
- [net] fix soft lockups/OOM with unix socket GC (Eugene Teo) [473263] {CVE-2008-5300}
- [block] enforce a minimum SG_IO timeout (Luis Goncalves) [475407] {CVE-2008-5700}
- [block] lockdep: make double_unlock_balance inline (part2) (Luis Goncalves)
- [tools] Add the SMI latency detector module from Jon Masters
- Patches from 2.6.24.7-rt26:
  - trace-histogram: handle clock going backwards
  - interrupt enabled in irq fix

* Wed Jan 07 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-98
- [net] sctp: overflow when FWD-TSN has bad stream ID (Eugene Teo) [478802] {CVE-2009-0065}
- [vfs] fix inotify watch removal/umount races (Eugene Teo) [472327] {CVE-2008-5182}
- [scsi] IBM SAN device handler bugfixes (Luis Goncalves)

* Mon Jan 05 2009 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-97
- Cherry-pick patches from 2.6.24.7-rt25:
  - ftrace: fix the preempt-disable start fix
  - rwlock: fix modification of owners race [472804]
  - rtmutex: fix rwlock boosting
  - rtmutex: force slow path for rw locks
  - rtmutex:  fix for rtmutex_adjust_readers
  - ftrace: fix task state printout
  - sched: remove useless nointeractive state
  - rtmutex: remove unused variable
  - rtmutex: unify state manipulation
  - rtmutex: remove uber optimization
  - rtmutex: remove useless schedule enforcement
  - rtmutex: prevent missed wakeups

* Tue Dec 30 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-96
- [tools] event trace syscall on i386 has bogus parameters (Steven Rostedt) [474683]
- [rtc] hwclock fails on mrg-rt kernel (Ken Cox) [465837]
- [time] additional fixes to adjtimex (Luis Goncalv) [472277]

* Mon Dec 1 2008 Clark Williams <williams@redhat.com> - 2.6.24.7-95
- [core] posix-timers race condition aditional fix (Luis Goncalv) [469724]
- [time] upstream backport of adjtimex cleanups (Luis Goncalv) [472277]

* Tue Nov 18 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-94
- [v4l] kernel: Avoid writing outside shadow.bytes array (Mauro Chehab) [471845]
- [wifi] libertas: fix buffer overrun (Luis Goncalves) [470762] {CVE-2008-5134}
- [vfs] file caps: always start with clear bprm->caps_* (Luis Goncalves) [470759]
- [net] netlink_broadcast calls yield(). Modified patch (Arnaldo Carvalho de Melo) [463207]

* Tue Nov 11 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-93
- [net] additional patch to the sockets issue (Luis Goncalves) [470429] {CVE-2008-5029}

* Wed Nov 05 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-92
- [net] fixed the 40ms latency patch from [460217]
- [net] kernel: Unix sockets kernel panic (David Miller) [470429] {CVE-2008-5029}

* Tue Nov 04 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-91
- [core] posix-timers race condition causes timer to seize up (Luis Goncalv) [469724]
- [tools] Lockdep fixes cause latency regression (Sripathi Kodi) [469186]
- [net] Spurious 40ms latency in messaging workloads (Chris Snook) [460217]

* Wed Oct 29 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24.7-90
- [fs] ext[234] directory corruption DoS (Luis Goncalves) [459577] {CVE-2008-3528}
- [mm] Missing randomisation for exec, heap, and libc (Luis Goncalves) [458797]
- [config] Disable CONFIG_COMPAT_BRK by default (Luis Goncalves) [458797]
- [sound] alsa: fix double free / memory leak in many codecs (Luis Goncalves) [460102]
- [net] sctp: oops when peer supports no AUTH [466080] (Eugene Teo) {CVE-2008-4576}
- [config] Disable KVM on MRG-RT kernel spec (Luis Goncalves) [468988]
- [core] x86_64 ia32 emulation leaks uninit. data (Luis Goncalves) [459505] {CVE-2008-0598}

* Tue Oct 28 2008 Clark Williams <williams@redhat.com> - 2.6.24.7-89
- [net] backported ixgb driver from 2.6.27 (Clark Williams) [466563]
- [rt] we are in synch with 2.6.24.7-rt21 (Luis Goncalves)
- [net] Update the igb driver with upstream (Arnaldo Carvalho de Melo) [466569]
- [scsi] added IBM device handler patches [467783]
- [config] turned on SCSI_DH and SCSI_DH_RDAC for device handler patches

* Thu Oct 23 2008 Clark Williams <williams@redhat.com> - 2.6.24.7-88
- [edac] Added amd64_edac driver from IBM (Vernon Maurey) [467739]
- [tools] Remove compat strict st functions (Steven Rostedt)
- [net] netlink_broadcast calls yield(). Deadlock on sirq-net-rx/2 (Steven rostedt) [463207]
- [scsi] turned off MSI and fixed sense handling for qla2xxx driver [467783]
- [tools] make dynamic ftrace much more robust (Steven Rostedt) [467781]
- [tools] update recordmcount.pl (Steven Rostedt) [467781]
- [net] Update the solarflare driver with upstream (Arnaldo Carvalho de Melo) [466571]
- [tools] event trace syscall on i386 has bogus parameters (Steven Rostedt) [455095]
- [scsi] Update the qla2xx driver with RHEL5.3 and upstream (Jon Masters) [466554]
- [net] Update the bnx2x driver with RHEL5.3 and upstream (Jon Masters) [466565]
- [config] Turn off building of ocfs2 filesystem module in MRG (Luis Goncalves) [468205]
- [config] Turn on building of driver modules added to MRG (Luis Goncalves) [468231]
- [net] Update the ixgbe driver with upstream (Arnaldo Carvalho de Melo) [466564]

* Mon Oct 20 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-87
- [net] Update the tg3 driver with RHEL5.3 and upstream (Luis Goncalves) [466558]
- [net] Update the cxgb3 driver with RHEL5.3 and upstream (Arnaldo Carvalho de Melo) [466568]
- [net] Update the e1000e driver with RHEL5.3 and upstream (Luis Goncalves) [466557]

* Wed Oct 15 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-86
- [mm] RT kernel fails to boot on Intel Caneland (16 and 24 cores) (Peter Zijlstra) [466341]

* Tue Oct 14 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-85
- [misc] rtc: panic on second use of SIGIO nofitication (Eugene Teo) [465745]
- [net] sctp: panic processing prot violation param (Luis Goncalves) [465731] {CVE-2008-4618}
- [rt] Warning from rt_mutex code while testing infiniband (Steven Rostedt) [465862]
- [syscall] avoid splice() to files opened with O_APPEND (Eugene Teo) [466708] {CVE-2008-4554}

* Wed Oct 03 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-84
- [net] e1000e: write protect ICHx NVM to prevent malicious write/erase (Luis Goncalves)
- [net] Update bnx2 driver to version 1.78 (Arnaldo Carvalho de Melo) [466153]

* Wed Oct 02 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-83
- [graph] i915 kernel drm driver arbitrary ioremap (Eugene Teo) [464507] {CVE-2008-3831}
- [syscall] Nano/Microsecond resolution for select() and poll() (Luis Goncalves) [466750]

* Mon Sep 29 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-82
- Corrected the changelog entry for -79 as the patch for BZ459956/CVE-2008-3792
  also fixes BZ464515/CVE-2008-4113.
- BZ462282 kernel: netlink: fix overrun in attribute iteration
- BZ461330 Update realtime kernel's lpfc version to 8.2.0.29

* Fri Sep 15 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-81
- Disabled CONFIG_RTMUTEX_CHECK on the production kernel (-rt)
- Added one more item to the IO-APIC quirk list

* Fri Sep 12 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-80
- Patches cherry-picked from -rt18:
  - seqlock serialize writes (Gregory Haskins)
  - Fix above patch that broke non PREEMPT_RT (Steven Rostedt)
  - Add sysctl to warn on RT task using non PI futex (Steven Rostedt)
  - lockdep debug fix int/atomic_t compile error (Steven Rostedt)
- Patches cherry-picked from -rt19:
  - rtmutex: integrity checks (Steven Rostedt)
  - Remove the hardcoded value of MAX_RT_PRIO (Ankita Garg)
  - BZ460455 R2:SAN:Hang triggered by filesystem testing on SAN
- Enabled CONFIG_RTMUTEX_CHECK on all kernel flavors for this release only

* Tue Sep 09 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-79
- FTRACE: do not trace init or exit sections
- BZ458016 kernel: random32: seeding improvement - added an enhancement to the
  first patch, suggested by Eugene Teo
- BZ461130 CVE-2008-3915 kernel: nfsd: fix buffer overrun decoding NFSv4 acl
- BZ459956 CVE-2008-3792 kernel: sctp: fix potential panics in the SCTP-AUTH API
- BZ464515 CVE-2008-4113 kernel: sctp_getsockopt_hmac_ident information
  disclosure. (solved by the previous patch too).
- BZ460094 CVE-2008-3526 kernel: sctp_setsockopt_auth_key() integer overflow
- BZ460395 CVE-2008-4445 sctp: fix random memory dereference with SCTP_HMAC_IDENT option
- BZ459942 nf_nat: use secure_ipv4_port_ephemeral() for NAT port randomization
- BZ457027 ide-cd: fix oops when using growisofs - added a second fix, pointed
  by comment #2 as necessary.
- BZ458350 fs/cifs/asn1.c:403: warning: comparison is always false due to
  limited range of data type - added small changes to keep in sync with upstream

* Thu Aug 21 2008 Clark Williams <williams@redhat.com> - 2.6.24-78
- enabled DEBUG_SPINLOCK_SLEEP and DEBUG_LIST in debug configuration
- BZ448574 kernel: increased MAX_STACK_TRACE_ENTRIES for debug kernel
- BZ459478 Long boot time and strange Hardware Clock message
- LOCKDEP performance improvements (related to the previous BZ)
- BZ459141 Add ftrace boot time nop replacement (removed ftrace daemon)
- the fix for BZ457507 CVE-2008-3534 created another issue, reported on the
  same BZ. This fix may also address BZ458487 (under testing)
- BZ459231 CVE-2008-3276 Linux kernel dccp_setsockopt_change() integer overflow
- BZ459462 kernel: binfmt_misc.c: avoid potential kernel stack overflow
- BZ459459 kernel: cpufreq: fix format string bug

* Wed Aug 13 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-77
- BZ458350 fs/cifs/asn1.c:403: warning: comparison is always false due to
  limited range of data type
- BZ458755 kernel: dlm: fix possible use-after-free
- BZ458756 kernel: dlm: check for null in device_write
- BZ458758 kernel: dlm: dlm/user.c input validation fixes (patch by Eugene Teo)
- shorten posix_cpu_timers/<CPU> kernel thread names

* Tue Aug 05 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-76
- BZ457012 ipv6: Use timer pending to fix bridge reference count problem
- BZ457014 pppoe: Check packet length on all receive paths
- BZ457019 pppoe: Unshare skb before anything else
- BZ457027 ide-cd: fix oops when using growisofs
- BZ457507 tmpfs: fix kernel BUG in shmem_delete_inode
- BZ457705 kernel: fix off-by-one error in iov_iter_advance()
- BZ457858 CVE-2008-3275: Linux kernel local filesystem DoS
- BZ457997 CVE-2008-3272: kernel snd_seq_oss_synth_make_info leak
- BZ458016 New: kernel: random32: seeding improvement
- BZ458340 parse_pmtmr() receives a (possible) ulong then stores that in a u32
- Enable panic_on_oops so that we are aligned with RHEL5.2
- Cleaned a few compile time warnings

* Wed Jul 30 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-75
- Selected relevant patches from -rt17

* Tue Jul 23 2008 Clark Williams <williams@redhat.com> - 2.6.24-74
- Replaced SCHED_FIFO spec violation patch
- added peterz's alloc_stack_early.patch for BZ453677 and BZ455747

* Wed Jul 16 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-73
- sched: fix the wrong time slice value for SCHED_FIFO tasks - BZ454913
- CVE-2008-2148 - fix sys_utimensat permissions checking - BZ455275
- CVE-2008-2372 - reinstate ZERO_PAGE optimization in get user pages - BZ452666
- upstream ftrace fix from Josh Triplett
- ftrace: only trace preempt off with preempt tracer
- rwlock: be more conservative in locking reader_lock_count (BZ452974)
- CVE-2008-2729 - extensively tested and certified it was fixed in -68
- Disabled CONFIG_FTRACE_SELFTEST and CONFIG_FTRACE_STARTUP_TEST 

* Wed Jul 09 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-72
- Added a fix for a potencial bug in inotify_user coalescing. bz453990
- Added a backport of SCHED_FIFO spec violation fix
- Added a backport of FUTEX_WAIT_BITSET. BZ429290
- Fixes preempt unsafe accesses to per_cpu variables (PPC64)

* Thu Jul 03 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-71
- Fixes warning seen when CONFIG_DEBUG_RT_MUTEXES is on.
- Added a fix for BZ452693

* Wed Jul 02 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-70
- Fix a race condition in COW logic
- Disable CONFIG_DMAR. Safest option in the presence of a broken BIOS.
- Removed work_around_downgrade_read.patch

* Wed Jun 25 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-69
- Removed old slab fix patch
- Added new cpu hotplug patch series

* Tue Jun 24 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-68
- Rebased the PREEMPT_RT patch to 2.6.24.7-rt14
- Added David S. Miller patch for sctp_add overflow check. BZ452483
- Removed patches that are no longer necessary
- Added fix for BZ434998 - x86_64--ia32_syscall_restart_fix
- Added fix for BZ437882 - x86_64--ptrace_sign_extend_orig_rax_to_64bits
- Removed sched-use-a-2d-bitmap-search-prio-cpu-R.patch

* Fri Jun 20 2008 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.24-66
- Applied fixes for the following CVE Security reports:
- CVE-2007-6282 - BZ404291
- CVE-2007-6694 - BZ396751
- CVE-2008-1615 - BZ431430
- CVE-2008-1673 - BZ443962
- CVE-2008-2136 - BZ446031
- CVE-2008-2148 - BZ446060
- CVE-2008-0598 - BZ451275
- Applied a fix for rwlock slowunlock mutex

* Fri Jun  6 2008 Clark Williams <williams@redhat.com> - 2.6.24-65
- replaced peterz's slab fix with v2 patch
- replaced rostedt's ftrace hotplug fix wth v2 patch

* Thu Jun  5 2008 Clark Williams <williams@redhat.com> - 2.6.24-64
- applied cpuprio reverse patch to workaround (BZ# 449676)
- applied patch to fix kdump on LS21 systems (BZ# 448715)
- applied ftrace fixes from rostedt
- applied slab fix from peterz
- applied radix tree lockdep fix from rostedt

* Tue Jun  3 2008 Clark Williams <williams@redhat.com> - 2.6.24-63
- applied rwlock-fixes.patch from rostedt
- added rwlock-torture test module

* Fri May 28 2008 Clark Williams <williams@redhat.com> - 2.6.24-62
- applied rwlock fix from rostedt (BZ# 446397)
- backed out the reverse patch from below
- added marker systemtap interface patch

* Thu May 27 2008 Clark Williams <williams@redhat.com> - 2.6.24-61
- applied rostedt's rwlock-multireader-reverse patch to test
  without rwlock patch
- turned off IRQSOFF_TRACER, PREEMPT_TRACER and DYNAMIC_FTRACE in
  debug configuration

* Tue May 27 2008 Clark Williams <williams@redhat.com> - 2.6.24-60
- rebased to 2.6.24.7-rt11
  - preempt __delay fix (Steven Rostedt)
  - load_balance breaks (Peter Zijlstra)
  - ftrace minor fixes (Steven Rostedt, Clark Williams,
                     and Abhishek Sagar)
  - disable ftrace daemon (Steven Rostedt)
  - sched_rt migration updates (Gregory Haskins)
  - nmi show regs fix (Hiroshi Shimamoto)
  - Trace histogram divide by zero fix (Carsten Emde)

* Sat May 24 2008 Clark Williams <williams@redhat.com> - 2.6.24-59
- rebased to 2.6.24.7-rt10
  - updated ftrace
  - lockbreak patches from pzijlstr
- minor compile fix for debugging kernel

* Thu May 22 2008 Clark Williams <williams@redhat.com> - 2.6.24-58
- added jocef's lock inversion fix for DIO
- added jocef's ext3 journal overflow fix

* Wed May 21 2008 Clark Williams <williams@redhat.com> - 2.6.24-57
- rebased RT patch to 2.6.24.7-rt9
  - miscellaneous rt fixes
  - rt_downgrade_write logic
- added solarflare NIC driver
- turned off building docs for all but noarch
- turned off CONFIG_FTRACE in debug kernel

* Tue May 20 2008 Clark Williams <williams@redhat.com> - 2.6.24-56
- rebased RT patch to 2.6.24.7-rt8
  - adaptive spinlocks
  - updated rwlocks-multi
- removed duplicate patches

* Thu May 15 2008 Clark Williams <williams@redhat.com> - 2.6.24-55
- added adaptive-spinlock-lite patch from rostedt

* Tue May 13 2008 Clark Williams <williams@redhat.com> - 2.6.24-54
- commented out all fast_gup patches (not just futex related)

* Tue May 13 2008 Clark Williams <williams@redhat.com> - 2.6.24-53
- Added upstream fix to poll (prevent early return)
- commented out fast_gup patches for test purposes

* Fri May  9 2008 Clark Williams <williams@redhat.com> - 2.6.24-52
- added work_around_downgrade_read patch from rostedt  (BZ# 445875)

* Fri May  9 2008 Clark Williams <williams@redhat.com> - 2.6.24-51
- turned off LOCK_STAT in trace kernel

* Thu May 08 2008 Clark Williams <williams@redhat.com> - 2.6.24-50
- rebased to 2.6.24.7 stable
- backed out hiroshi's nmi patches
- added acme's caching of pci_find_capability() patch

* Thu May 01 2008 Clark Williams <williams@redhat.com> - 2.6.24-49
- changed debuginfo paths to remove update conflicts (BZ# 355321)
- added .build-id to deal with building on Fedora (newer rpmbuild)
- upstream patches from tglx for hrtimers
- upstream NMI patches from hiroshi
- ftrace patch from rostedt
- TSC sync fix patch from bhavana
- upstream hrtimer fix from tglx where net traffic starves timer

* Sat Apr 26 2008 Clark Williams <williams@redhat.com> - 2.6.24-48
- added rostedt's rwlockmulti patch series

* Wed Apr 23 2008 Clark Williams <williams@redhat.com> - 2.6.24-47
- turned on config options:
  	   SCHEDSTATS
	   TIMER_STATS
	   MODULE_SRCVERSION_ALL
	   PRINT_QUOTA_WARNING
	   USB_LIBUSUAL
	   X86_REBOOTFIXUPS
- turned off config options:
  	   ACPI_DOCK
	   THINKPAD_ACPI_DOCK
- removed SYSFS_DEPRECATED_V2

* Tue Apr 22 2008 Clark Williams <williams@redhat.com> - 2.6.24-46
- turned off VIRTUALIZATIO, PARAVIRT* and KVM config options
- changed all AGP_* config options to modules

* Tue Apr 22 2008 Clark Williams <williams@redhat.com> - 2.6.24-45
- changed CONFIG_SCSI_SCAN_ASYNC to 'n' (fixes various panics
  on boot where system unable to local root volume)

* Thu Apr 17 2008 Clark Williams <williams@redhat.com> - 2.6.24-44
- turned off MTD_CK804XROM config (again)
- added fast_gup_patchlet from peterz to fix PTE race on PAE systems
- added vsyscall64 dummy patch from lgoncalve to silence warning on boot

* Wed Apr 16 2008 Clark Williams <williams@redhat.com> - 2.6.24-43
- turned on CONFIG_SYSFS_DEPRECATED* (rostedt says fixes 32-bit boot)
- turned off CONFIG_BACKTRACE_SELF_TEST
- turned off CONFIG_HIGHPTE for peterz (check fast_gup failure)

* Mon Apr 14 2008 Clark Williams <williams@redhat.com> - 2.6.24-42
- added i386 version of IOAPIC quirk from mschmidt

* Thu Apr 10 2008 Clark Williams <williams@redhat.com> - 2.6.24-41
- added CONFIG_DEBUG_LOCKDEP to config-trace

* Thu Apr 10 2008 Clark Williams <williams@redhat.com> - 2.6.24-40
- added backport of arjan's upstream stacktrace rework
- added peterz's patch to shorten softirq process names
- changed <asm/highmem.h> to <linux/highmem.h> in fast_gup patch
- turned on LOCK_STAT in trace kernels

* Wed Apr 09 2008 Clark Williams <williams@redhat.com> - 2.6.24-39
- add missing "*/" to quirk patch to get rid of compiler warning
- add <asm/highmem.h> to fast_gup patch to pick up kunmap_atomic 
  prototype in 32-bit compile

* Wed Apr 09 2008 Clark Williams <williams@redhat.com> - 2.6.24-38
- added tglx's patch to make vsyscall64 safe
- added peterz's futex-fast_gup patch to remove mmap_sem from
  fast path of shared futexes

* Wed Apr 09 2008 Clark Williams <williams@redhat.com> - 2.6.24-37
- More missed config options (debugging on in production kernel)

* Tue Apr 08 2008 Clark Williams <williams@redhat.com> - 2.6.24-36
- Turned off other config options missed in initial merge

* Tue Apr 08 2008 Clark Williams <williams@redhat.com> - 2.6.24-35
- turned off EDAC configuration option for i686 (again)

* Tue Apr 08 2008 Clark Williams <williams@redhat.com> - 2.6.24-34
- debugging work on config file change

* Tue Apr 08 2008 Clark Williams <williams@redhat.com> - 2.6.24-33
- reworked config files to use same logic as Fedora kernel

* Thu Apr 03 2008 Clark Williams <williams@redhat.com> - 2.6.24-32
- turned off EDAC configuration option for i686

* Thu Apr 03 2008 Clark Williams <williams@redhat.com> - 2.6.24-31
- additional systems added to IOAPIC quirk
- swap deadlock patch from upstream
- new NetXen driver patches (BZ# 438987)
- RELOCATABLE and CRASH_DUMP turned on in configs
- added EDAC patches for IBM HS21 and LS21 (BZ# 438471)
- turned off NMI watchdog by default (dropped nmi_watchdog_default.patch)

* Tue Mar 25 2008 Clark Williams <williams@redhat.com> - 2.6.24-30
- rebased to latest stable 2.6.24.4
- rebased to latest rt 2.6.24.4-rt4
- switched to unified -rt patch (rather than patch series)
- BZ# 438217 addressed by stable patch
- Turned off CONFIG_MTD_CK804XROM to get rid of bogus warning message
- added back quiet-plit-warning.patch (inadvertently dropped)
  (BZ#  432377)

* Wed Mar  5 2008 Clark Williams <williams@redhat.com> - 2.6.24-29
- re-enabled MODULE_UNLOAD (breaks RHTS tests)
- updated rostedt's rt-balance-check patch

* Tue Mar  4 2008 Clark Williams <williams@redhat.com> - 2.6.24-28
- added rostedt's rt-balance-check-rq.patch for bug reported by IBM

* Tue Mar  4 2008 Clark Williams <williams@redhat.com> - 2.6.24-27
- fixed breakage in 2.6.24.3 stable patch that broke vanilla

* Tue Mar  4 2008 Clark Williams <williams@redhat.com> - 2.6.24-26
- fixed error in declaring stable update patch

* Mon Mar  3 2008 Clark Williams <williams@redhat.com> - 2.6.24-25
- rebased to latest stable 2.6.24.3
- rebased to latest -rt 2.6.24.3-rt3
- added dledford's ofed-1.3 patches
- added new config files
- updated configs to reflect ofed patches
- added rostedt's fix for level triggered interrupt affinity
  (BZ# 433534)

* Thu Feb 14 2008 Clark Williams <williams@redhat.com> - 2.6.24-24
- renamed bz235099-idle-load-fix.patch to bz253099-idle-load-fix.patch
- fixedup incorrect entries in specfile due to above

* Mon Feb 11 2008 Clark Williams <williams@redhat.com> - 2.6.24-24
- fixed specfile error (omitted stablerev in EXTRAVERSION edit)

* Mon Feb 11 2008 Clark Williams <williams@redhat.com> - 2.6.24-23
- rebased to 2.6.24.1 stable patch
- renamed config files due to rebase
- added Al Viro's vmsplice exploit patch (BZ # 432251)

* Tue Feb 05 2008 Clark Williams <williams@redhat.com> - 2.6.24-22
- added jcm's pci quirk patches to deal with IOAPIC masking oddities
  - linux-2.6-rt-quirky-ioapic-legacy-mask-unmask-workaround-jcm.patch
  - preempt-irqs-x86-64-ioapic-mask-quirk-jcm.patch

* Thu Jan 31 2008 Clark Williams <williams@redhat.com> - 2.6.24-21
- more patches pulled in from .21 tree:
	printk-in-atomic.patch
	RHEL5.1_fix_tscsync.patch
- fixed typo in linux-2.6-rt-oom-kill.patch
- removed linux-2.6-x86-crash-driver (for now)
  i386/x86_64 merge caused problems; will bring back if needed

* Tue Jan 29 2008 Clark Williams <williams@redhat.com> - 2.6.24-20
- fixed more patch damage on bz253099-idle-load-fix.patch

* Tue Jan 29 2008 Clark Williams <williams@redhat.com> - 2.6.24-19
- fixed patch damage in nmi_watchdog_default

* Tue Jan 29 2008 Clark Williams <williams@redhat.com> - 2.6.24-18
- fixed up mismerge (again) in linux-2.6-rt-oom-kill
  (was overwritten from stale git tree)
- pulled more patches from .21 tree:
  	 limit-i386-ram-to-16gb.patch
	 RT-die.patch
	 nmi_watchdog_default.patch
  	 pci-nommconf-noseg.patch
  	 bz253099-idle-load-fix.patch

* Mon Jan 28 2008 Clark Williams <williams@redhat.com> - 2.6.24-17
- fixed specfile error with upstream_sublevel macro

* Mon Jan 28 2008 Clark Williams <williams@redhat.com> - 2.6.24-16
- removed source file for patch-2.6.24-rc8.bz2

* Mon Jan 28 2008 Clark Williams <williams@redhat.com> - 2.6.24-15
- rebased to released 2.6.24 kernel and -rt1 patch series

* Wed Jan 23 2008 Clark Williams <williams@redhat.com> - 2.6.24-14
- added jstultz and lclaudio's vsyscall64 fixes

* Tue Jan 22 2008 Clark Williams <williams@redhat.com> - 2.6.24-13
- fix mis-merge in linux-2.6-rt-oom-kill done when rebasing to 2.6.24

* Mon Jan 21 2008 Clark Williams <williams@redhat.com> - 2.6.24-12
- fixed specfile typo in applying implement-rt-downgrade-write.patch

* Mon Jan 21 2008 Clark Williams <williams@redhat.com> - 2.6.24-11
- Added patch from rostedt to implement rt_downgrade_write()

* Fri Jan 18 2008 Clark Williams <williams@redhat.com> - 2.6.24-10
- modified trace kernel configs to set CONFIG_WAKEUP_TIMING

* Thu Jan 17 2008 Clark Williams <williams@redhat.com> - 2.6.24-9
- fixed config file issues

* Thu Jan 17 2008 Clark Williams <williams@redhat.com> - 2.6.24-8
- fixed thinko in the spec file (didn't change source1)

* Thu Jan 17 2008 Clark Williams <williams@redhat.com> - 2.6.24-7
- rebased to 2.6.24-rc8-rt1

* Tue Jan 15 2008 Clark Williams <williams@redhat.com> - 2.6.24-6
- fixed some damaged patches

* Mon Jan 14 2008 Clark Williams <williams@redhat.com> - 2.6.24-6
- rebased to 2.6.24-rc7
- rebased to 2.6.24-rc7-rt2

* Fri Jan 11 2008 Clark Williams <williams@redhat.com> - 2.6.24-5
- cleaned up usage of kversion and rpmversion macros
  (this fixed debuginfo files issues)
- rebased config files to kernel-2.6.24-*.config

* Thu Jan 10 2008 Clark Williams <williams@redhat.com> - 2.6.24-4
- removed incorrect move of vanilla config after oldconfig

* Thu Jan 10 2008 Clark Williams <williams@redhat.com> - 2.6.24-3
- added arch comment to otherwise fine vanilla i686 config

* Thu Jan 10 2008 Clark Williams <williams@redhat.com> - 2.6.24-2
- updated vanilla config for i686

* Thu Jan 10 2008 Clark Williams <williams@redhat.com> - 2.6.24-1
- rebased to 2.6.24-rc5 release candidate
- rebased to 2.6.24-rc5-rt1 rt patch

* Mon Dec 10 2007 Clark Williams <williams@redhat.com> - 2.6.23-7
- rebased to 2.6.23.9 stable patch
- rebased to 2.6.23.9-rt12 rt patch

* Wed Nov 19 2007 Clark Williams <williams@redhat.com> - 2.6.23-6
- moved linux-2.6-build-nonintconfig.patch to end of patch
  definition section

* Wed Nov 19 2007 Clark Williams <williams@redhat.com> - 2.6.23-5
- Fixed patch syntax error

* Wed Nov 19 2007 Clark Williams <williams@redhat.com> - 2.6.23-4
- rebased to 2.6.23.3
- rebased to realtime patch 2.6.23.1-rt11

* Wed Nov  7 2007 Clark Williams <williams@redhat.com> - 2.6.23-3
- rebased to 2.6.23.1-rt8

* Tue Oct 16 2007 Clark Williams <williams@redhat.com> - 2.6.23-2
- added printk to megasas_NODELAY patch to report the
  IRQ number and whether it is SHARED or NODELAY
- fixed typo in version.patch

* Mon Oct 15 2007 Clark Williams <williams@redhat.com> - 2.6.23-1
- rebased to kernel 2.6.23.1
- using "broken-out" 2.6.23-rt1 realtime patch (~400 patches)
- changed patch strategy to use Fedora-style ApplyPatch macro

* Mon Oct  8 2007 Clark Williams <williams@redhat.com> - 2.6.21-41
- added lwoodman's oomkill modification
- added rostedt's AIO workaround (BZ#263461)

* Thu Sep 20 2007 Clark Williams <williams@redhat.com> - 2.6.21-39
- Modified acme's patch to make selecting IRQ type a module option
  (BZ#250266)

* Wed Sep 12 2007 Clark Williams <williams@redhat.com> - 2.6.21-38
- added fixes from rostetd and peterz for RCU problem (BZ#245338)
- addded fixes from tglx, acme, and lclaudio (BZ#245247)

* Thu Aug 30 2007 Clark Williams <williams@redhat.com> - 2.6.21-37
- added rostedt's fix for latency tracer (no BZ)

* Fri Aug 24 2007 Clark Williams <williams@redhat.com> - 2.6.21-36
- replaced old softirq patches with new one from rostedt (BZ#248352)

* Thu Aug 23 2007 Clark Williams <williams@redhat.com> - 2.6.21-36
- added patch to change megasas interrupt from IRQF_SHARED to
  IRQF_NODELAY  (BZ#250266)

* Fri Aug 17 2007 Clark Williams <williams@redhat.com> - 2.6.21-36
- added fix for futex unlock problem (BZ#241731)

* Thu Jul 26 2007 Clark Williams <williams@redhat.com> - 2.6.21-35
- added two -rt bugfixes from mingo
- added updated Infiniband patches from dledford (BZ#236771 and BZ#246763)

* Thu Jul 12 2007 Clark Williams <williams@redhat.com> - 2.6.21-34
- added AMD TSC fix patch from bnagendra (BZ#230638)

* Mon Jul  9 2007 Clark Williams <williams@redhat.com> - 2.6.21-33
- added srostedt patch for BUG_ON in exit.c

* Wed Jun 20 2007 Clark Williams <williams@redhat.com> - 2.6.21-32
- changed lock in nmi print to raw spinlock (srostedt)
- removed duplicate print preempt disable warning (srostedt)
- annotated changelog entries with BZ numbers
- added crash driver for i686 (streeter) (BZ# 241810)

* Tue Jun 19 2007 Clark Williams <williams@redhat.com> - 2.6.21-32
- updated softirq migration patch from srostedt (#BZ 244282)
- added fix for printk while in atomic operation (srostedt)

* Mon Jun 18 2007 Clark Williams <williams@redhat.com> - 2.6.21-31
- updated linux-2.6-rt-oom.patch from lwoodman
- added IOAPIC fix from tglx and srostedt (BZ#236150)
- added AMD TSC sync patches from bnagendra (BZ#230638)

* Fri Jun 15 2007 Clark Williams <williams@redhat.com> - 2.6.21-30
- added 'kernel' provide to specfile (should allow installonly)
- added hrtimer fix from tglx (suspend fix)
- added OOM patch from lwoodman to allow disabling of oom-kill
- deleted many old patches from CVS tree

* Fri Jun 15 2007 Clark Williams <williams@redhat.com> - 2.6.21-29
- fix for BZ#242630 from acme (oops on sysrq-M)
- config changes to remove CONFIG_CRASH_DUMP
- config changes to relocate x86_64 kernel to 2M
  (get out of the way of the std crash dump kernel)

* Wed Jun 13 2007 Clark Williams <williams@redhat.com> - 2.6.21-28
- fixed checkin of binary patch

* Wed Jun 13 2007 Clark Williams <williams@redhat.com> - 2.6.21-27
- rebased to 2.6.21.5 + 2.6.21.4-rt10
- Fixed config options to build i686 kernels with PAE
- reworked IBM rmem patch (fixed my brain damage)
- added bnx2 upstream fixes
- reverted rhel5-oom patch (now upstream)
- reverted oprofile patches (now upstream)

* Mon Jun 11 2007 Clark Williams <williams@redhat.com> - 2.6.21-26
- private build with 2.6.21.4-rt10

* Thu Jun  7 2007 John W. Linville <linville@redhat.com> - 2.6.21-25
- Update linux-2.6-wireless.patch and git-wireless-dev.patch
- Update git-iwlwifi.patch (version 0.0.24)

* Mon Jun  4 2007 Arnaldo Carvalho de Melo <acme@redhat.com> - 2.6.21-24
- bnx2 upstream backport - commented out till next rebuild by clark

* Sat Jun  2 2007 Jon Masters <jcm@redhat.com> - 2.6.21-23
- Apply rmem module fixes after other rmem patches.

* Fri Jun  1 2007 Jon Masters <jcm@redhat.com> - 2.6.21-22
- Apply rmem module fixes to enable rmem module support.

* Fri Jun  1 2007 Jon Masters <jcm@redhat.com> - 2.6.21-21
- Revert RHEL5 crash driver backport.
- Revert RHEL5 devmem patch.

* Thu May 31 2007 Jon Masters <jcm@redhat.com> - 2.6.21-20
- Turn dynticks off by default.

* Thu May 31 2007 Jon Masters <jcm@redhat.com> - 2.6.21-19
- Fix a bug in Futex unlocking sematics.

* Thu May 31 2007 Guy Streeter <streeter@redhat.com> - 2.6.21-18
- Fix crash driver module build on x86_64

* Thu May 31 2007 Arnaldo Carvalho de Melo <acme@redhat.com> - 2.6.21-17
- Fix oprofile bug on x86-64 SMP

* Thu May 31 2007 Guy Streeter <streeter@redhat.com> - 2.6.21-16
- Add the crash driver module (bz 241810)

* Thu May 24 2007 John W. Linville <linville@redhat.com> - 2.6.21-15
- update wireless bits from current F-7 kernel

* Wed May 23 2007 Clark Williams <williams@redhat.com> - 2.6.21-14
- rebased to patch-2.6.21-rt7
- fixed missing #endif in above patch with rt7-rtc-fix.patch

* Tue May 22 2007 Clark Williams <williams@redhat.com> - 2.6.21-13
- added definition of NLA_BINARY to include/net/netlink.h

* Tue May 22 2007 Clark Williams <williams@redhat.com> - 2.6.21-12
- grabbed linville's latest rawhide wireless patches

* Mon May 21 2007 Clark Williams <williams@redhat.com> - 2.6.21-11
- rebased to patch-2.6.21-rt6

* Mon May 21 2007 Clark Williams <williams@redhat.com> - 2.6.21-10
- rebased to patch-2.6.21-rt5

* Fri May 18 2007 Guy Streeter <streeter@redhat.com>
- Try to get the "vanilla" kernel to boot

* Fri May 18 2007 Clark Williams <williams@redhat.com> - 2.6.21-9
- switched to 2.6.21-rt4

* Fri May 18 2007 Clark Williams <williams@redhat.com> - 2.6.21-8
- checked in the patch-2.6.21-rt3 file

* Fri May 18 2007 Clark Williams <williams@redhat.com> - 2.6.21-7
- switched to 2.6.21-rt3 realtime patch

* Wed May 16 2007 Clark Williams <williams@redhat.com> - 2.6.21-6
- added IBM ptrace fix

* Wed May 16 2007 Clark Williams <williams@redhat.com> - 2.6.21-5
- switched over to Ingo's 2.6.21-rt2 realtime patch
- ditched the "delay disable irq" hack from previous version

* Fri May 11 2007 Clark Williams <williams@redhat.com> - 2.6.21-4
- try disabling the "delay disable irq" patch for "irq: no one cared" problem

* Thu May 10 2007 Clark Williams <williams@redhat.com> - 2.6.21-3
- added wireless patches from linville

* Wed May  9 2007 Clark Williams <williams@redhat.com> - 2.6.21-2
- fixed thinko in i686 vanilla config

* Wed May  9 2007 Clark Williams <williams@redhat.com> - 2.6.21-1
- rebased to 2.6.21

* Tue May  8 2007 Clark Williams <williams@redhat.com> - 2.6.20-39
- dzickus found CONFIG_DEBUG_INFO not on in i686 vanilla config

* Mon May  7 2007 Clark Williams <williams@redhat.com> - 2.6.20-38
- tracked down missing files section path for vanilla-devel package

* Fri May  4 2007 Clark Williams <williams@redhat.com> - 2.6.20-37
- fixed nonexistant file in vanilla-debuginfo

* Fri May  4 2007 Clark Williams <williams@redhat.com> - 2.6.20-36
- fixed error in i686 trace config

* Fri May  4 2007 Clark Williams <williams@redhat.com> - 2.6.20-35
- added trace configs to Source. sigh...

* Fri May  4 2007 Clark Williams <williams@redhat.com> - 2.6.20-34
- try it again, this time with the trace configs checked in

* Fri May  4 2007 Clark Williams <williams@redhat.com> - 2.6.20-33
- reordered build to do vanilla last

* Thu May  3 2007 Clark Williams <williams@redhat.com> - 2.6.20-32
- Build "trace" kernel
- turn on buildvanilla for i686 and x86_64 only

* Wed May  2 2007 Guy Streeter <streeter@redhat.com> - 2.6.20-31
- Build "vanilla" kernel

* Tue May  1 2007 Guy Streeter <streeter@redhat.com> - 2.6.20-30
- Add "RT" to uname when CONFIG_PREEMPT_RT is set

* Fri Apr 27 2007 Guy Streeter <streeter@redhat.com> - 2.6.20-29
- turn buildrt off in general, on for i686 and x86_64 only
- turn builddebug off for noarch

* Fri Apr 27 2007 Clark Williams <williams@redhat.com> - 2.6.20-28
- added missing ipath module for IB system in production config

* Fri Apr 27 2007 Clark Williams <williams@redhat.com> - 2.6.20-27
- added missing ipath module for IB system

* Fri Apr 27 2007 Clark Williams <williams@redhat.com> - 2.6.20-26
- really fixed oldconfig problem with configfiles

* Fri Apr 27 2007 Clark Williams <williams@redhat.com> - 2.6.20-25
- fixed oldconfig problem with configfiles

* Fri Apr 27 2007 Clark Williams <williams@redhat.com> - 2.6.20-24
- updated config files for production kernels

* Fri Apr 20 2007 Clark Williams <williams@redhat.com> - 2.6.20-23
- added posix cpu timer fix
- added mm/slab.c fix for drain_array()

* Thu Apr 19 2007 Clark Williams <williams@redhat.com> - 2.6.20-22
- don't apply the tg3 thread patch for now

* Tue Apr 17 2007 Clark Williams <williams@redhat.com> - 2.6.20-21
- more cleanup on config files

* Tue Apr 17 2007 Clark Williams <williams@redhat.com> - 2.6.20-20
- fixed config file breakage from previous build
- reworked config files for option consistency

* Mon Apr 16 2007 Clark Williams <williams@redhat.com> - 2.6.20-19
- removed all -b arguments in patch commands

* Fri Apr 13 2007 Clark Williams <williams@redhat.com> - 2.6.20-18
- fix breakage due to incorrect patch application

* Fri Apr 13 2007 Clark Williams <williams@redhat.com> - 2.6.20-17
- fixed infiniband options in i686 config files

* Fri Apr 13 2007 Clark Williams <williams@redhat.com> - 2.6.20-16
- fixed typo in x86_64 config files

* Fri Apr 13 2007 Clark Williams <williams@redhat.com> - 2.6.20-15
- added inifiniband patch from Doug Ledford
- Added 'unprotected_address_space' command line
  switch from Dave Jones
- Added netif patch from Doug Ledford

* Fri Apr 13 2007 Clark Williams <williams@redhat.com> - 2.6.20-14
- Backed out tg3 patch for testing

* Wed Apr 11 2007 Jon Masters <jcm@redhat.com> - 2.6.20-13
- Fix generation of Module.symvers for out-of-tree 3rd party driver building.

* Tue Apr 10 2007 Clark Williams <williams@redhat.com> - 2.6.20-12
- removed calls to /sbin/weak-modules during pre/posts

* Tue Apr 10 2007 Clark Williams <williams@redhat.com> - 2.6.20-11
- Fixed missing spin_unlock in tg3 patch

* Mon Apr  9 2007 Clark Williams <williams@redhat.com> - 2.6.20-10
- applied IBM tg3 patch

* Thu Apr  5 2007 Clark Williams <williams@redhat.com> - 2.6.20-8
- renamed release to iteration
- fixed duplication problem using dist tag

* Tue Apr  3 2007 Clark Williams <williams@redhat.com> - 2.6.20-5
- turned off kernel-rt-header generation

* Tue Mar 20 2007 Clark Williams <williams@redhat.com> - 2.6.20-3
- building 2.6.20 base with 2.6.20-rt8 patch

* Mon Mar  5 2007 Clark Williams <williams@redhat.com> - 2.6.20-1
- Major surgery to be kernel-rt specific

* Thu Nov  9 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc5-git2
- Bump HZ to 1000

* Wed Nov  8 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc5-git1

* Tue Nov  7 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc5

* Mon Nov  6 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc4-git11

* Tue Oct 31 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc4

* Sun Oct 29 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc3

* Fri Oct 13 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc2
